<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class insucom_animated_text extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'animation-text';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Animation Text', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		$this->layout_options();			
		$this->meta_options();	
		$this->design_options();
	}
	
	/**
    * Layout Options
    */
    private function layout_options() {
	
	
		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
	
		$this->add_control( 'textItems', [
			'label'       => esc_html__( 'Animated Text Content', 'gazania-extra' ),
			'type'        => \Elementor\Controls_Manager::REPEATER,
			'default'     => [
				[
					'animated_text'        => esc_html__( 'Magazine Theme', 'gazania-extra' ),
				]
			],

			'fields'      => [

				[
					'name'  => 'animated_text',
					'label' => __( 'Give animated text list', 'gazania-extra' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => __( 'Magazine Theme' , 'gazania-extra' ),
					'label_block' => true,
				],


			],
			'title_field' => "{{name}}"
		] );
			

		
		
		$this->end_controls_section();
	
	}
	

	/**
    * Meta Options
    */
    private function meta_options() {
	
	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

 
		
	
		$this->end_controls_section();
	
	}	
	
	/**
    * Design Options
    */
    private function design_options() {
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Slider Typography', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'block_one_title_typography',
              'label' => esc_html__( 'Post Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .blog-post-tab-wrap.post-block-item.post-block-item-one .grid-content-bottom h3.post-title',
           ]
        );		
		
		

		
		$this->end_controls_section();
	
	}	
		


	protected function render() {
		
		
		$settings = $this->get_settings_for_display(); 
		$textItems = $settings['textItems'];

?>

    <!-- row start -->
    <div class="row">
        <!-- col start -->
        <div class="col-lg-12">
            <!-- section txt start -->

            <div class="animated-text-wrapper-r">
                <div class="animated-text-r">

                	<?php 
						foreach ( $textItems as $item ):
					?>

                    <div class="animated-text-content-r"><?php echo $item['animated_text']; ?></div>

                    <?php endforeach; ?>


                </div>
            </div>



            <!--<div class="animated-text-wrapper-r">
                <div class="animated-text-r">
                    <div class="animated-text-content-r">identify the essential&nbsp;</div>
                    <div class="animated-text-content-r">keep it simple&nbsp;</div>
                    <div class="animated-text-content-r">be different&nbsp;</div>
                    <div class="animated-text-content-r">identify the essential&nbsp;</div>
                    <div class="animated-text-content-r">keep it simple&nbsp;</div>
                    <div class="animated-text-content-r">be different&nbsp;</div>
                    <div class="animated-text-content-r">identify the essential&nbsp;</div>
                    <div class="animated-text-content-r">keep it simple&nbsp;</div>
                    <div class="animated-text-content-r">be different&nbsp;</div>
                    <div class="animated-text-content-r">identify the essential&nbsp;</div>
                </div>
            </div>

        -->


            <!-- section txt end -->
        </div>
        <!-- col end -->
    </div>
    <!-- row end -->


		
<?php 


}
		
  	
	
}

