<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class insucom_post_block_slider extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-block-slider-one';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Post Slider 1', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		$this->layout_options();		
		$this->post_query_options();	
		$this->meta_options();	
		$this->design_options();
	}
	
	/**
    * Layout Options
    */
    private function layout_options() {
	
	
		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
					

		$this->add_responsive_control(
			'post_slider_one_img_height',
			[
				'label' =>esc_html__( 'Set Post Image height', 'insucom-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 900,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 600,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' =>400,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 900,
				],
				
				'selectors' => [
					'{{WRAPPER}} .theme-main-slider-wrapper article.post-block-style-one-wrapper .post-block-style-one-inner .post-block-media-wrap a img' => 'height: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);

		$this->end_controls_section();
	
	}
	
	/**
    * Post Query Options
    */
    private function post_query_options() {
	
	
		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'insucom-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'insucom-extra'),
                    'rand' => esc_html__('Random Post', 'insucom-extra'),
					'title'         => __( 'Title Sorting Post', 'insucom-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'insucom-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'insucom-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'insucom-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'insucom-extra'),
                    'ASC' => esc_html__('Ascending', 'insucom-extra'),
                ],
            ]
        );
		
		
		// Post Categories
		
		$this->add_control(
            'post_categories',
            [
                'type'      => \Elementor\Controls_Manager::SELECT2,
				'label' =>esc_html__('Select Categories', 'insucom-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );
	
		
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'insucom-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '2',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'insucom-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'insucom-extra'),
               'label_off' => esc_html__('No', 'insucom-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'insucom-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );
		
		
		$this->end_controls_section();
	
	}	
	
	/**
    * Meta Options
    */
    private function meta_options() {
	
	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );
		

     	$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'insucom-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'insucom-extra'),
                'label_off' => esc_html__('No', 'insucom-extra'),
                'default' => 'yes',
            ]
        );
		
		$this->add_control(
            'display_post_block_meta',
            [
                'label' => esc_html__('Display Post Meta', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );


 
		
	
		$this->end_controls_section();
	
	}	
	
	/**
    * Design Options
    */
    private function design_options() {
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Slider Typography', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_list_title',
              'label' => esc_html__( 'Post Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .theme-main-slider-wrapper article.post-block-style-one-wrapper .post-block-style-one-inner .post-item-title h2.post-title',
           ]
        );	


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'post_block_list_excerpt',
				'label' => __( 'Post Excerpt Typography', 'insucom-extra' ),
				'selector' => '{{WRAPPER}} .theme-main-slider-wrapper article.post-block-style-one-wrapper .post-block-style-one-inner .post-excerpt-box p',
			]
		);
		
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_list_cat',
              'label' => esc_html__( 'Category Meta Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .theme-main-slider-wrapper article.post-block-style-one-wrapper .post-block-style-one-inner .post-category-box a',
           ]
        );
		
		 
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_list_meta',
              'label' => esc_html__( 'Post Meta Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .theme-main-slider-wrapper article.post-block-style-one-wrapper .post-block-style-one-inner .post-block-meta-list',
           ]
        );


		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Post Title Length', 'insucom-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );

        $this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'ennlil-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );
		

		
		$this->end_controls_section();
	
	}	
		


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 
		
		$display_blog_excerpt = $settings['display_excerpt'];
		$display_blog_cat = $settings['display_cat'];
		$display_post_block_meta = $settings['display_post_block_meta'];

		
		$args = [
            'post_type' => 'post',
            'post_status' => 'publish',
			'order' => $settings['post_ordering'],
			'posts_per_page' => $settings['post_number'],
			'ignore_sticky_posts' => 1,
        ];
		
		// Category
        if ( ! empty( $settings['post_categories'] ) ) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	
		
		// Post Offset		
		if($settings['enable_offset_post'] == 'yes') {
			$args['offset'] = $settings['post_offset_count'];
		}

		// Query
        $query = new \WP_Query( $args ); ?>
		





		
<?php if ( $query->have_posts() ) : ?>


	<div class="theme-main-slider-wrapper swiper mySwiper">

		<div class="swiper-wrapper">


			<?php while ($query->have_posts()) : $query->the_post(); ?>


			<article <?php post_class('swiper-slide post-block-style-one-wrapper'); ?>>

				<div class="post-block-style-one-inner">


						<div class="post-block-media-wrap">
							<a href="<?php the_permalink(); ?>">
								<img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">
							</a>
						</div>
					
						<div class="post-block-content-wrap">
					
								
								<?php if($display_blog_cat=='yes'): ?>	
								<div class="post-category-box">
								<?php require INSUCOM_THEME_DIR . '/template-parts/cat-alt-template.php'; ?>
								</div>
								<?php endif; ?>	
								
								<div class="post-item-title">
									<h2 class="post-title">
									<a href="<?php the_permalink(); ?>"><?php echo esc_html( wp_trim_words(get_the_title(), $title_limit,'') ); ?></a>
									</h2>
								</div>

								<?php if($display_post_block_meta=='yes'): ?>
								<div class="post-block-meta-list">
									
									<div class="post-meta-author-box">
										BY <?php echo get_the_author_link(); ?>
									</div>

									<div class="post-meta-date-box">
										<?php echo esc_html( get_the_date( 'F j, Y' ) ); ?>
									</div>
									
								</div>
								<?php endif; ?>
						

								<?php if($display_blog_excerpt =='yes'): ?> 
								<div class="post-excerpt-box">
									<p><?php echo esc_html( wp_trim_words(get_the_excerpt(), $content_limit ,'') );?></p>
								</div>
								<?php endif; ?>	
								
							</div>
			

					</div>
				
				</article>

							

			<?php endwhile; ?>
	
			</div>

			<div class="swiper-button-next"></div>
      		<div class="swiper-button-prev"></div>
      		<div class="swiper-pagination"></div>


	</div>

		<?php wp_reset_postdata(); ?>

		<?php endif; ?>
		

	
	<?php 
}
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
			'taxonomy'    => 'category',
			'hide_empty'  => true
		) );

		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->slug]  = [$post->name];
		}
		return $cat_list;
	  
	}		
	
}

