<?php
/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */

class Insucom_Heading_Title_Widget extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'insucom-heading-title';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Heading Title: 01', 'insucom-master');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-archive-title';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['insucom_widgets'];
    }

    /**
     * Register Elementor widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls()
    {

		$this->start_controls_section(
            'settings_heading',
            [
                'label' => esc_html__('General Settings', 'libo-master'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		


        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'libo-master'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'description' => esc_html__('enter  title.', 'libo-master'),
                'default' => esc_html__('Fetaured Posts', 'libo-master')
            ]
        );

        $this->add_control(
            'title_style',
            [
                'label'     =>esc_html__( 'Select Title Style', 'insucom-extra' ),
                'type'      => \Elementor\Controls_Manager::SELECT,
                'default'   => 'one',
                'options'   => [
                        'one'    =>esc_html__( 'Style 1', 'insucom-extra' ),
                        'two'    =>esc_html__( 'Style 2', 'insucom-extra' ),
                    ],
            ]
        );


        $this->add_control(
            'alignment',
            [
                'label' => esc_html__('Alignment', 'libo-master'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'libo-master'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'libo-master'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'libo-master'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle' => true,
                'selectors' => [
                    "{{WRAPPER}} .theme-section-title" => "text-align: {{VALUE}}"
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'styling_heading',
            [
                'label' => esc_html__('Styling Settings', 'libo-master'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
	
		
		$this->add_control(
            'heading_bottom_space',
            [
                'label' => esc_html__('Heading Bottom Space', 'libo-master'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .theme-section-title h2' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
		
		
        $this->end_controls_section();
		
        $this->start_controls_section(
            'styling_typogrpahy_heading',
            [
                'label' => esc_html__('Typography Settings', 'libo-master'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
		
        $this->add_group_control(\Elementor\Group_Control_Typography::get_type(), [
            'name' => 'section_title_typography',
            'label' => esc_html__('Title Typography', 'libo-master'),
            'selector' => "{{WRAPPER}} .theme-section-title h2"
        ]);
		

        $this->end_controls_section();
		

    }

    /**
     * Render Elementor widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $heading_style = $settings['title_style'];

        ?>
        
			<div class="theme-section-title <?php echo esc_attr( ( 'center' === $settings['alignment'] ) ? 'title-centerr' : ' ' );?> <?php echo esc_attr( ( 'right' === $settings['alignment'] ) ? 'title-rightt' : ' ' );?>">

                <h2 class="title <?php echo esc_attr($heading_style);?>"><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                
            </div>


        <?php
    }
}

