<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_banner_onee extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-banner-home-one';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Banner:1', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_banner_one', [
            'label' => esc_html__( 'Banner Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type sbanner short description here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'banner_feature_image', [
            'label'   => __( 'Choose Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control( 'video_btn_text', [
            'label'       => __( 'Video Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Watch Video', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control(
            'video_link', [
                'label' => __( 'Insert Self Hosted Video URL Link in Video format(eg. mp4/flv etc).', 'insucom-extra' ),
                'type'        => \Elementor\Controls_Manager::URL,

                'default'     => [
                    'url' => 'https://www.youtube.com/watch?v=9Oia-ki4iyw',
                ],
                
                'description' => esc_html__( 'Enter Video URL', 'insucom-extra' )
            ]
        );


        $this->end_controls_section();




		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        extract($settings); 


		
		?>

      <!--      hero-->
      <section class="hero-area w-full relative theme-hero-style-one">
        <div
          class="h-full flex xl:justify-center justify-start items-center relative z-20"
        >
          <div class="theme-container xl:mx-auto">
            <h1
              data-aos="fade-up"
              class="text-primary-900 xl:text-[96px] sm:text-6xl text-5xl font-bold xl:leading-[95px] mb-5">

              <?php echo wp_kses_post( $settings['title'] ); ?>

            </h1>
            <p class="text-primary-900 text-base leading-7 mb-9">
              <?php echo wp_kses_post( $settings['description'] ); ?>
            </p>
            <div
              class="flex flex-col sm:flex-row sm:space-x-10 space-y-10 sm:space-y-0 sm:items-center"
            >
              <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>">
                <div
                  class="px-[46px] py-[20px] bg-primary-500 rounded-lg text-white text-lg spline-sans leading-none hover:bg-primary-900 common-trans inline"
                >
                  <span><?php echo $settings['btn_text'] ?></span>
                </div>
              </a>
              <button
                data-aos="fade-left"
                type="button"
                class="sm:flex hidden space-x-5 items-center"
              >

              <a href="<?php echo esc_url( $settings['video_link']['url'] ) ?>" class="video-play-btn">
                <div class="w-[55px] h-[55px] relative">
                  <div
                    class="w-full h-full rounded-full flex justify-center items-center bg-primary-500 relative z-10"
                  >
                    <span>
                      <svg
                        width="12"
                        height="16"
                        viewBox="0 0 12 16"
                        fill="none"
                        xmlns="http://www.w3.org/2000/svg"
                      >
                        <path
                          d="M11.2812 6.71875C11.7188 7 12 7.5 12 8C12 8.53125 11.7188 9.03125 11.2812 9.28125L2.28125 14.7812C1.8125 15.0625 1.21875 15.0938 0.75 14.8125C0.28125 14.5625 0 14.0625 0 13.5V2.5C0 1.96875 0.28125 1.46875 0.75 1.21875C1.21875 0.9375 1.8125 0.9375 2.28125 1.25L11.2812 6.71875Z"
                          fill="white"
                        />
                      </svg>
                    </span>
                  </div>
                  <div class="button-outer-circle has-scale-animation"></div>
                  <div
                    class="button-outer-circle has-scale-animation has-delay-short"
                  ></div>
                </div>
                <span class="font-semibold text-lg spline-sans text-primary-900 video-text-one"
                  ><?php echo $settings['video_btn_text'] ?></span
                >

                </a>


              </button>
            </div>
          </div>
        </div>
        <div
          data-aos="fade-left"
          data-aos-duration="1000"
          class="hero-image-1 w-full h-full absolute left-0 top-0 z-10 bg-no-repeat bg-cover"
          style="background-image: url('<?php echo esc_url( $settings['banner_feature_image']['url'] ); ?>')"
        ></div>
      </section>


	<?php 


	}
				

}

