<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_banner_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-banner-home-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Banner:2', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_banner_two', [
            'label' => esc_html__( 'Banner Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type sbanner short description here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'banner_feature_image', [
            'label'   => __( 'Choose Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control( 'video_btn_text', [
            'label'       => __( 'Video Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Watch Video', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control(
            'video_link', [
                'label' => __( 'Insert Self Hosted Video URL Link in Video format(eg. mp4/flv etc).', 'insucom-extra' ),
                'type'        => \Elementor\Controls_Manager::URL,

                'default'     => [
                    'url' => 'https://www.youtube.com/watch?v=9Oia-ki4iyw',
                ],
                
                'description' => esc_html__( 'Enter Video URL', 'insucom-extra' )
            ]
        );

        $this->add_control( 'section_bg_image', [
            'label'   => __( 'Choose Bcakground Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->add_control( 'banner_shape_image1', [
            'label'   => __( 'Choose Shape 1 Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'banner_shape_image2', [
            'label'   => __( 'Choose Shape 2 Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'banner_shape_image3', [
            'label'   => __( 'Choose Shape 3 Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'banner_shape_image4', [
            'label'   => __( 'Choose Shape 4 Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->end_controls_section();




		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        extract($settings); 


		
		?>

      <!--      hero -->
      <section class="hero-area-2 home-banner-style-two w-full lg:h-[758px] py-20 relative" style="background-image:url(<?php echo esc_url( $settings['section_bg_image']['url'] ); ?>;)">
        <div class="theme-container h-full mx-auto">
          <div
            class="w-full grid lg:grid-cols-2 grid-cols-1 gap-[30px] lg:gap-0 h-full justify-center items-center"
          >
            <div class="article-area">
              <h1
                class="text-primary-900 xl:text-[70px] text-[50px] font-bold leading-[60px] xl:leading-[70px] mb-5 text-center lg:text-start"
              >
                <?php echo wp_kses_post( $settings['title'] ); ?>

              </h1>

              <p class="text-primary-900 text-base leading-7 mb-9 text-center lg:text-start">

                <?php echo wp_kses_post( $settings['description'] ); ?>

              </p>

              <div
                class="flex justify-center lg:justify-start space-x-10 items-center"
              >
                <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>">
                  <div
                    class="px-[46px] py-[20px] bg-primary-500 hover:bg-primary-900 common-trans rounded-lg text-white text-lg spline-sans leading-none"
                  >
                    <span><?php echo $settings['btn_text'] ?></span>
                  </div>
                </a>
                <button
                  data-aos="fade-left"
                  type="button"
                  class="sm:flex hidden space-x-5 items-center"
                >

                <a href="<?php echo esc_url( $settings['video_link']['url'] ) ?>" class="video-play-btn">

                  <div class="w-[55px] h-[55px] relative">
                    <div
                      class="w-full h-full rounded-full flex justify-center items-center bg-primary-500 relative z-10"
                    >
                      <span>
                        <svg
                          width="12"
                          height="16"
                          viewBox="0 0 12 16"
                          fill="none"
                          xmlns="http://www.w3.org/2000/svg"
                        >
                          <path
                            d="M11.2812 6.71875C11.7188 7 12 7.5 12 8C12 8.53125 11.7188 9.03125 11.2812 9.28125L2.28125 14.7812C1.8125 15.0625 1.21875 15.0938 0.75 14.8125C0.28125 14.5625 0 14.0625 0 13.5V2.5C0 1.96875 0.28125 1.46875 0.75 1.21875C1.21875 0.9375 1.8125 0.9375 2.28125 1.25L11.2812 6.71875Z"
                            fill="white"
                          />
                        </svg>
                      </span>
                    </div>
                    <div class="button-outer-circle has-scale-animation"></div>
                    <div
                      class="button-outer-circle has-scale-animation has-delay-short"
                    ></div>
                  </div>
                  <span
                    class="font-semibold text-lg spline-sans text-primary-900 video-text-one"
                    ><?php echo $settings['video_btn_text'] ?></span
                  >

                </a>


                </button>
              </div>
            </div>
            <div
              data-aos="fade-left"
              data-aos-duration="1000"
              class="thumb-area xl:h-auto h-[500px] transform xl:scale-100 scale-90"
            >
              <img
                src="<?php echo esc_url( $settings['banner_feature_image']['url'] ); ?>"
                alt=""
                class="w-full h-full object-contain"
              />
            </div>
          </div>
        </div>
        <div>
          <div class="shape absolute left-5 bottom-[314px]">
            <img
              src="<?php echo esc_url( $settings['banner_shape_image1']['url'] ); ?>"
              alt=""
              class="opacity-[0.1]"
            />
          </div>
          <div class="shape absolute left-[80px] bottom-[160px]">
            <img src="<?php echo esc_url( $settings['banner_shape_image2']['url'] ); ?>" alt="" />
          </div>
          <div class="shape absolute left-5 bottom-5">
            <img
              src="<?php echo esc_url( $settings['banner_shape_image3']['url'] ); ?>"
              alt=""
              class="opacity-[0.1]"
            />
          </div>
          <div class="shape absolute left-[218px] bottom-5">
            <img
              src="<?php echo esc_url( $settings['banner_shape_image4']['url'] ); ?>"
              alt=""
              class="opacity-[0.1]"
            />
          </div>
        </div>
      </section>



	<?php 


	}
				

}

