<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */

//namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_blog_grid_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-home-blog-grid-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Blog V2', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		$this->layout_options();		
		$this->post_query_options();	
		$this->meta_options();	
		$this->design_options();
	}
	
	/**
    * Layout Options
    */
    private function layout_options() {
	
	
		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		$this->add_control(
			'post_col_block_title',
			[
				'label' => __( 'Section Title', 'finmag-extra' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'Blog Insights', 'finmag-extra' ),
				'placeholder' => __( 'Type Your title here', 'finmag-extra' ),
			]
		);
		
		$this->add_responsive_control(
			'post_block_list_img_height',
			[
				'label' =>esc_html__( 'Set Post Image height', 'insucom-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 240,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 240,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 240,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 240,
				],
				
				'selectors' => [
					'{{WRAPPER}} .home-blog-one-grid-wrap .blog-post-thumb img' => 'height: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);	


		
		$this->end_controls_section();
	
	}
	
	/**
    * Post Query Options
    */
    private function post_query_options() {
	
	
		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'insucom-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'insucom-extra'),
                    'rand' => esc_html__('Random Post', 'insucom-extra'),
					'title'         => __( 'Title Sorting Post', 'insucom-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'insucom-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'insucom-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'insucom-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'insucom-extra'),
                    'ASC' => esc_html__('Ascending', 'insucom-extra'),
                ],
            ]
        );
		
		
		// Post Categories
		
		$this->add_control(
            'post_categories',
            [
                'type'      => \Elementor\Controls_Manager::SELECT2,
				'label' =>esc_html__('Select Categories', 'insucom-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );
	
		
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'insucom-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '2',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'insucom-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'insucom-extra'),
               'label_off' => esc_html__('No', 'insucom-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'insucom-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );

        // Specific Posts by ID.
        $this->add_control(
            'post_ids',
            [
                'type'        => \Elementor\Controls_Manager::TEXT,
                'label'       => __( 'Show specific posts by ID', 'insucom-extra' ),
                'placeholder' => __( 'ex.: 256, 54, 78', 'insucom-extra' ),
                'description'   => __( 'Paste post ID\'s separated by commas. To find ID, click edit post and you\'ll find it in the browser address bar', 'insucom-extra' ),
                'default'     => '',
                'separator'     => 'before',
                'label_block' => true,
            ]
        );
		
		
		$this->end_controls_section();
	
	}	
	
	/**
    * Meta Options
    */
    private function meta_options() {
	
	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );
		

     	$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'insucom-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'insucom-extra'),
                'label_off' => esc_html__('No', 'insucom-extra'),
                'default' => 'yes',
            ]
        );


		$this->add_control(
         	'display_author',
         	[
				 'label' => esc_html__('Display Author', 'insucom-extra'),
				 'type' => \Elementor\Controls_Manager::SWITCHER,
				 'label_on' => esc_html__('Yes', 'insucom-extra'),
				 'label_off' => esc_html__('No', 'insucom-extra'),
				 'default' => 'yes',
         	]
     	);


		$this->add_control(
            'display_date',
            [
                'label' => esc_html__('Display Date', 'insucom-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'insucom-extra'),
                'label_off' => esc_html__('No', 'insucom-extra'),
                'default' => 'yes',
            ]
        );
		
	
		$this->end_controls_section();
	
	}	
	
	/**
    * Design Options
    */
    private function design_options() {
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Slider Typography', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_top_title',
              'label' => esc_html__( 'Top Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h2.post-block-title',
           ]
        );

        $this->add_responsive_control(
            'post_block_top_title_margin',
            [
                'label' => esc_html__( 'Top Title Margin', 'insucom-extra' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h2.post-block-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_top_subtitle',
              'label' => esc_html__( 'Top Sub Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h4.post-sub-title',
           ]
        );

        $this->add_responsive_control(
            'post_block_top_sub_title_margin',
            [
                'label' => esc_html__( 'Top Sub Title Margin', 'insucom-extra' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h4.post-sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_top_btn',
              'label' => esc_html__( 'Top Button Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-btn a',
           ]
        );


        $this->add_responsive_control(
            'post_block_top_btn_margin',
            [
                'label' => esc_html__( 'Top button Margin', 'insucom-extra' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_home_grid_title',
              'label' => esc_html__( 'Post Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-block-style-one-inner .post-block-content-wrap h3.post-title',
           ]
        );	

		

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'post_block_home_grid_excerpt',
				'label' => __( 'Post Excerpt Typography', 'insucom-extra' ),
				'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-block-style-one-inner .post-block-content-wrap .post-excerpt-box p',
			]
		);
		


		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Post Title Length', 'insucom-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );

        $this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'insucom-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );
		

		
		$this->end_controls_section();
	
	}	
		


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$string_ID = $settings['post_ids'];
        $post_ID = ( ! empty( $string_ID ) ) ? array_map( 'intval', explode( ',', $string_ID ) ) : '';

		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 

		$display_blog_excerpt = $settings['display_excerpt'];
		$display_blog_cat = $settings['display_cat'];
		$display_blog_author = $settings['display_author'];
		$display_blog_date = $settings['display_date'];
		
		
		$args = [
            'post_type' => 'post',
            'post_status' => 'publish',
			'order' => $settings['post_ordering'],
			'posts_per_page' => $settings['post_number'],
			'ignore_sticky_posts' => 1,
        ];
		
		// Category
        if ( ! empty( $settings['post_categories'] ) ) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	
		
		// Specific Posts by ID's
        if ( ! empty( $settings['post_ids'] ) ) {
            $args['post__in'] = $post_ID;
        }

		// Post Offset		
		if($settings['enable_offset_post'] == 'yes') {
			$args['offset'] = $settings['post_offset_count'];
		}

		// Query
        $query = new \WP_Query( $args ); ?>
		
		
		<?php if ( $query->have_posts() ) : ?>


      <!--      blog section two-->
      <section class="blog-section-two w-full pb-[240px]">
        <div class="theme-container mx-auto">
          <div class="w-full relative">
            <h2 class="headline-default text-primary-900 mb-[60px] text-center blog-home-title-wrap">
              <?php echo wp_kses_post( $settings['post_col_block_title']  ); ?>
            </h2>
            <div
              class="grid xl:grid-cols-3 sm:grid-cols-2 grid-cols-1 gap-[30px]"
            >

            <?php while ($query->have_posts()) : $query->the_post(); ?>

              <div
                class="blog-item-2 w-full border border-primaryBorder group overflow-hidden"
              >
                <div class="w-full h-[269px] relative">
                  <div class="w-full h-full overflow-hidden">
                    <img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>" class="w-full h-full object-cover common-trans transform scale-100 group-hover:scale-105">
                  </div>
                  <div
                    style="box-shadow: 0px 23px 49px rgba(26, 9, 63, 0.1)"
                    class="absolute -bottom-[33px] right-8 w-[65px] h-[65px] rounded-full border-4 border-white bg-primary-500 flex justify-center items-center"
                  >
                    <div class="blog-two-meta">
                      <p
                        class="text-center text-white text-lg spline-sans font-semibold leading-none"
                      >
                        <?php echo get_the_date( 'j' ); ?>
                      </p>
                      <p class="text-white text-base leading-none"><?php echo get_the_date( 'M' ); ?></p>
                    </div>
                  </div>
                </div>
                <div class="pl-[30px] pt-5 pb-12">
                  <div class="blog-owner flex space-x-5 items-center mb-5">
                    <div class="w-[60px] h-[60px] rounded-full overflow-hidden cutsom-author-thumb">


                       <?php echo get_avatar( get_the_author_meta( 'ID' ), 60 ); ?>


                    </div>
                    <h2
                      class="text-gray-800 text-lg font-bold spline-sans leading-7"
                    >
                      Albert Flores
                    </h2>
                  </div>
                  <p
                    class="text-primary-100 font-semibold spline-sans leading-[27px] text-lg mb-10"
                  >
                    <?php echo esc_html( wp_trim_words(get_the_excerpt(), $content_limit ,'') );?>
                  </p>
                  <div class="flex space-x-20 items-center">
                    <a href="<?php the_permalink(); ?>">
                      <div class="flex space-x-3 items-center">
                        <span
                          class="text-lg font-semibold spline-sans text-primary-900"
                          >Read More</span
                        >
                        <span
                          class="transform translate-x-0 group-hover:translate-x-2 common-trans"
                        >
                          <svg
                            width="15"
                            height="13"
                            viewBox="0 0 15 13"
                            fill="none"
                            xmlns="http://www.w3.org/2000/svg"
                          >
                            <path
                              d="M13.6875 7.71875L8.6875 12.7188C8.5 12.9062 8.25 13 8 13C7.71875 13 7.46875 12.9062 7.28125 12.7188C6.875 12.3438 6.875 11.6875 7.28125 11.3125L10.5625 8H1C0.4375 8 0 7.5625 0 7C0 6.46875 0.4375 6 1 6H10.5625L7.28125 2.71875C6.875 2.34375 6.875 1.6875 7.28125 1.3125C7.65625 0.90625 8.3125 0.90625 8.6875 1.3125L13.6875 6.3125C14.0938 6.6875 14.0938 7.34375 13.6875 7.71875Z"
                              fill="#028835"
                            />
                          </svg>
                        </span>
                      </div>
                    </a>
                    <div class="flex-1 h-[1px] bg-primaryBorder"></div>
                  </div>
                </div>
              </div>

              <?php endwhile; ?>


            </div>



          </div>
        </div>
      </section>


        <?php wp_reset_postdata(); ?>
		
		<?php endif; ?>

	
	<?php 
}
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
			'taxonomy'    => 'category',
			'hide_empty'  => true
		) );

		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->slug]  = [$post->name];
		}
		return $cat_list;
	  
	}		
	
}

