<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */

//namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_blog_grid extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-home-blog-grid';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Blog V1', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {
		$this->layout_options();		
		$this->post_query_options();	
		$this->meta_options();	
		$this->design_options();
	}
	
	/**
    * Layout Options
    */
    private function layout_options() {
	
	
		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		$this->add_control(
			'post_col_block_title',
			[
				'label' => __( 'Section Title', 'finmag-extra' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'Blog Insights', 'finmag-extra' ),
				'placeholder' => __( 'Type Your title here', 'finmag-extra' ),
			]
		);
		
		$this->add_responsive_control(
			'post_block_list_img_height',
			[
				'label' =>esc_html__( 'Set Post Image height', 'insucom-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 240,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 240,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 240,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 240,
				],
				
				'selectors' => [
					'{{WRAPPER}} .home-blog-one-grid-wrap .blog-post-thumb img' => 'height: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);	


		
		$this->end_controls_section();
	
	}
	
	/**
    * Post Query Options
    */
    private function post_query_options() {
	
	
		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'insucom-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'insucom-extra'),
                    'rand' => esc_html__('Random Post', 'insucom-extra'),
					'title'         => __( 'Title Sorting Post', 'insucom-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'insucom-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'insucom-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'insucom-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'insucom-extra'),
                    'ASC' => esc_html__('Ascending', 'insucom-extra'),
                ],
            ]
        );
		
		
		// Post Categories
		
		$this->add_control(
            'post_categories',
            [
                'type'      => \Elementor\Controls_Manager::SELECT2,
				'label' =>esc_html__('Select Categories', 'insucom-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );
	
		
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'insucom-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '2',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'insucom-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'insucom-extra'),
               'label_off' => esc_html__('No', 'insucom-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'insucom-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );

        // Specific Posts by ID.
        $this->add_control(
            'post_ids',
            [
                'type'        => \Elementor\Controls_Manager::TEXT,
                'label'       => __( 'Show specific posts by ID', 'insucom-extra' ),
                'placeholder' => __( 'ex.: 256, 54, 78', 'insucom-extra' ),
                'description'   => __( 'Paste post ID\'s separated by commas. To find ID, click edit post and you\'ll find it in the browser address bar', 'insucom-extra' ),
                'default'     => '',
                'separator'     => 'before',
                'label_block' => true,
            ]
        );
		
		
		$this->end_controls_section();
	
	}	
	
	/**
    * Meta Options
    */
    private function meta_options() {
	
	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );
		

     	$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'insucom-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'insucom-extra'),
                'label_off' => esc_html__('No', 'insucom-extra'),
                'default' => 'yes',
            ]
        );


		$this->add_control(
         	'display_author',
         	[
				 'label' => esc_html__('Display Author', 'insucom-extra'),
				 'type' => \Elementor\Controls_Manager::SWITCHER,
				 'label_on' => esc_html__('Yes', 'insucom-extra'),
				 'label_off' => esc_html__('No', 'insucom-extra'),
				 'default' => 'yes',
         	]
     	);


		$this->add_control(
            'display_date',
            [
                'label' => esc_html__('Display Date', 'insucom-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'insucom-extra'),
                'label_off' => esc_html__('No', 'insucom-extra'),
                'default' => 'yes',
            ]
        );
		
	
		$this->end_controls_section();
	
	}	
	
	/**
    * Design Options
    */
    private function design_options() {
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Slider Typography', 'insucom-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_top_title',
              'label' => esc_html__( 'Top Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h2.post-block-title',
           ]
        );

        $this->add_responsive_control(
            'post_block_top_title_margin',
            [
                'label' => esc_html__( 'Top Title Margin', 'insucom-extra' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h2.post-block-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_top_subtitle',
              'label' => esc_html__( 'Top Sub Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h4.post-sub-title',
           ]
        );

        $this->add_responsive_control(
            'post_block_top_sub_title_margin',
            [
                'label' => esc_html__( 'Top Sub Title Margin', 'insucom-extra' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-title h4.post-sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_top_btn',
              'label' => esc_html__( 'Top Button Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-btn a',
           ]
        );


        $this->add_responsive_control(
            'post_block_top_btn_margin',
            [
                'label' => esc_html__( 'Top button Margin', 'insucom-extra' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .home-blog-one-grid-wrap .post-blocks-column-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'post_block_home_grid_title',
              'label' => esc_html__( 'Post Title Typography', 'insucom-extra' ),
              'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-block-style-one-inner .post-block-content-wrap h3.post-title',
           ]
        );	

		

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'post_block_home_grid_excerpt',
				'label' => __( 'Post Excerpt Typography', 'insucom-extra' ),
				'selector' => '{{WRAPPER}} .home-blog-one-grid-wrap .post-block-style-one-inner .post-block-content-wrap .post-excerpt-box p',
			]
		);
		


		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Post Title Length', 'insucom-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );

        $this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'insucom-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );
		

		
		$this->end_controls_section();
	
	}	
		


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$string_ID = $settings['post_ids'];
        $post_ID = ( ! empty( $string_ID ) ) ? array_map( 'intval', explode( ',', $string_ID ) ) : '';

		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 

		$display_blog_excerpt = $settings['display_excerpt'];
		$display_blog_cat = $settings['display_cat'];
		$display_blog_author = $settings['display_author'];
		$display_blog_date = $settings['display_date'];
		
		
		$args = [
            'post_type' => 'post',
            'post_status' => 'publish',
			'order' => $settings['post_ordering'],
			'posts_per_page' => $settings['post_number'],
			'ignore_sticky_posts' => 1,
        ];
		
		// Category
        if ( ! empty( $settings['post_categories'] ) ) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	
		
		// Specific Posts by ID's
        if ( ! empty( $settings['post_ids'] ) ) {
            $args['post__in'] = $post_ID;
        }

		// Post Offset		
		if($settings['enable_offset_post'] == 'yes') {
			$args['offset'] = $settings['post_offset_count'];
		}

		// Query
        $query = new \WP_Query( $args ); ?>
		
		
		<?php if ( $query->have_posts() ) : ?>


            <!--blog-->
            <section class="blog-area home-blog-one w-full lg:py-[120px] py-[60px]">
                <div class="theme-container mx-auto">
                    <h2
                        class="headline-default text-center text-primary-900 lg:mb-[60px] mb-[30px] blog-home-title-wrap"
                        >
                        <?php echo wp_kses_post( $settings['post_col_block_title']  ); ?>
                    </h2>
                    <div
                        class="grid lg:grid-cols-3 sm:grid-cols-2 grid-cols-1 xl:gap-[30px] gap-5"
                        >

                        <?php while ($query->have_posts()) : $query->the_post(); ?>

                        <div
                            class="blog-item group w-full overflow-hidden rounded bg-secondary hover:bg-white transition-all duration-300 ease-in-out"
                            >
                            <div>
                                <div class="w-full h-[286px] relative">
                                    <div class="w-full h-full">

                                        <img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">

                                    </div>
                                    <div
                                        class="px-5 py-2.5 rounded bg-primary-500 absolute left-10 bottom-10"
                                        >
                                        <div class="flex space-x-2.5 items-center">
                                            <span>
                                                <svg
                                                    width="14"
                                                    height="16"
                                                    viewBox="0 0 14 16"
                                                    fill="none"
                                                    xmlns="http://www.w3.org/2000/svg"
                                                    >
                                                    <path
                                                        d="M7 8C4.78125 8 3 6.21875 3 4C3 1.8125 4.78125 0 7 0C9.1875 0 11 1.8125 11 4C11 6.21875 9.1875 8 7 8ZM5.5625 9.5H8.40625C11.5 9.5 14 12 14 15.0938C14 15.5938 13.5625 16 13.0625 16H0.90625C0.40625 16 0 15.5938 0 15.0938C0 12 2.46875 9.5 5.5625 9.5Z"
                                                        fill="white"
                                                        />
                                                </svg>
                                            </span>
                                            <span class="text-lg spline-sans font-semibold text-white author-link-box"
                                                ><?php echo get_the_author_link(); ?></span
                                                >
                                        </div>
                                    </div>
                                </div>
                                <div class="xl:p-7 p-3">
                                    <a href="<?php the_permalink(); ?>">
                                        <h2
                                            class="xl:text-lg xl:leading-7 text-md font-bold spline-sans text-primary-900 mb-5"
                                            >

                                            <?php echo esc_html( wp_trim_words(get_the_title(), $title_limit,'') ); ?>

                                        </h2>
                                    </a>
                                    <p class="xl:text-base text-sm text-primary-100 mb-5">
                                        <?php echo esc_html( wp_trim_words(get_the_excerpt(), $content_limit ,'') );?>
                                    </p>
                                    <div class="w-full h-[1px] bg-primaryBorder mb-5"></div>
                                    <div class="w-full flex justify-between items-center mb-14">
                                        <div class="flex space-x-2.5 items-center">
                                            <span
                                                >
                                                <svg
                                                    width="14"
                                                    height="16"
                                                    viewBox="0 0 14 16"
                                                    fill="none"
                                                    xmlns="http://www.w3.org/2000/svg"
                                                    >
                                                    <path
                                                        d="M4.75 2H9.25V0.75C9.25 0.34375 9.5625 0 10 0C10.4062 0 10.75 0.34375 10.75 0.75V2H12C13.0938 2 14 2.90625 14 4V14C14 15.125 13.0938 16 12 16H2C0.875 16 0 15.125 0 14V4C0 2.90625 0.875 2 2 2H3.25V0.75C3.25 0.34375 3.5625 0 4 0C4.40625 0 4.75 0.34375 4.75 0.75V2ZM1.5 7.75H4V6H1.5V7.75ZM1.5 9.25V11.25H4V9.25H1.5ZM5.5 9.25V11.25H8.5V9.25H5.5ZM10 9.25V11.25H12.5V9.25H10ZM12.5 6H10V7.75H12.5V6ZM12.5 12.75H10V14.5H12C12.25 14.5 12.5 14.2812 12.5 14V12.75ZM8.5 12.75H5.5V14.5H8.5V12.75ZM4 12.75H1.5V14C1.5 14.2812 1.71875 14.5 2 14.5H4V12.75ZM8.5 6H5.5V7.75H8.5V6Z"
                                                        fill="#028835"
                                                        />
                                                </svg>
                                            </span>
                                            <span class="xl:text-base text-sm text-primary-100"
                                                ><?php echo esc_html( get_the_date( 'M j, Y' ) ); ?></span
                                                >
                                        </div>
                                        <div class="flex space-x-2.5 items-center">
                                            <span
                                                >
                                                <svg
                                                    width="22"
                                                    height="16"
                                                    viewBox="0 0 22 16"
                                                    fill="none"
                                                    xmlns="http://www.w3.org/2000/svg"
                                                    >
                                                    <path
                                                        d="M7.5 0C11.0625 0 14 2.46875 14 5.5C14 8.5625 11.0625 11 7.5 11C6.90625 11 6.34375 10.9375 5.78125 10.8125C4.84375 11.4062 3.46875 12 1.75 12C1.4375 12 1.15625 11.8438 1.0625 11.5312C0.9375 11.25 0.96875 10.9375 1.1875 10.6875C1.21875 10.6875 1.90625 9.9375 2.40625 8.9375C1.53125 8 1 6.8125 1 5.5C1 2.46875 3.90625 0 7.5 0ZM6.125 9.34375C6.59375 9.46875 7.03125 9.5 7.5 9.5C10.25 9.5 12.5 7.71875 12.5 5.5C12.5 3.3125 10.25 1.5 7.5 1.5C4.71875 1.5 2.5 3.3125 2.5 5.5C2.5 6.625 3.03125 7.4375 3.5 7.90625L4.25 8.6875L3.75 9.65625C3.625 9.84375 3.5 10.0625 3.375 10.2812C3.9375 10.125 4.46875 9.875 5 9.53125L5.53125 9.21875L6.125 9.34375ZM14.7812 4.03125C18.25 4.15625 21 6.5625 21 9.5C21 10.8125 20.4375 12 19.5625 12.9375C20.0625 13.9375 20.75 14.6875 20.7812 14.6875C21 14.9375 21.0312 15.25 20.9062 15.5312C20.8125 15.8438 20.5312 16 20.2188 16C18.5 16 17.125 15.4062 16.1875 14.8125C15.625 14.9375 15.0625 15 14.5 15C11.9375 15 9.71875 13.75 8.65625 11.9375C9.1875 11.875 9.71875 11.75 10.1875 11.5625C11.0625 12.75 12.6562 13.5 14.5 13.5C14.9375 13.5 15.375 13.4688 15.8438 13.3438L16.4375 13.2188L16.9688 13.5312C17.5 13.875 18.0312 14.125 18.5938 14.2812C18.4688 14.0625 18.3438 13.8438 18.2188 13.6562L17.7188 12.6875L18.4688 11.9062C18.9375 11.4375 19.5 10.625 19.5 9.5C19.5 7.4375 17.5 5.75 14.9688 5.53125L15 5.5C15 5 14.9062 4.5 14.7812 4.03125Z"
                                                        fill="#028835"
                                                        />
                                                </svg>
                                            </span>
                                            <span class="xl:text-base text-sm text-primary-100"
                                                >Comments (<?php echo get_comments_number(); ?>)</span
                                                >
                                        </div>
                                    </div>
                                    <div class="mb-7">
                                        <a href="<?php the_permalink(); ?>">
                                            <div
                                                class="px-[30px] py-[14px] border border-primary-500 group-hover:bg-primary-500 common-trans rounded-lg inline"
                                                >
                                                <span
                                                    class="text-lg text-primary-900 group-hover:text-white common-trans font-semibold spline-sans"
                                                    >Read More</span
                                                    >
                                            </div>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>


                        <?php endwhile; ?>


                    </div>
                </div>
            </section>

        <?php wp_reset_postdata(); ?>
		
		<?php endif; ?>

	
	<?php 
}
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
			'taxonomy'    => 'category',
			'hide_empty'  => true
		) );

		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->slug]  = [$post->name];
		}
		return $cat_list;
	  
	}		
	
}

