<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_contact_info extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-home-contact-infobox';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact info Box', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_banner_one', [
            'label' => esc_html__( 'Banner Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type sbanner short description here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'banner_feature_image', [
            'label'   => __( 'Choose Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control( 'video_btn_text', [
            'label'       => __( 'Video Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Watch Video', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control(
            'video_link', [
                'label' => __( 'Insert Self Hosted Video URL Link in Video format(eg. mp4/flv etc).', 'insucom-extra' ),
                'type'        => \Elementor\Controls_Manager::URL,

                'default'     => [
                    'url' => 'https://www.youtube.com/watch?v=9Oia-ki4iyw',
                ],
                
                'description' => esc_html__( 'Enter Video URL', 'insucom-extra' )
            ]
        );


        $this->end_controls_section();




		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        extract($settings); 


		
		?>



      <div
        class="faq-page-wrapper contact-info-custom-wrapper"
      >
        <div class="theme-container mx-auto">
          <div class="grid sm:grid-cols-3 grid-cols-1 lg:gap-[30px] gap-5">
            <div
              data-aos="fade-up"
              data-aos-duration="1000"
              data-aos-delay="100"
              style="
                box-shadow: 0px 4.4px 12px -1px rgba(19, 16, 34, 0.06),
                  0px 2px 6.4px -1px rgba(19, 16, 34, 0.03);
              "
              class="item w-full"
            >
              <div
                class="w-full lg:h-[324px] h-[290px] relative overflow-hidden xl:bg-white bg-primary-50 rounded"
              >
                <div class="flex justify-center">
                  <div>
                    <div
                      class="mt-[50px] xl:mb-[90px] mb-10 flex justify-center relative z-10"
                    >
                      <span>
                        <svg
                          width="30"
                          height="41"
                          viewBox="0 0 30 41"
                          fill="none"
                          xmlns="http://www.w3.org/2000/svg"
                        >
                          <path
                            d="M13.125 39.0625C9.0625 33.9844 0 21.875 0 15C0 6.71875 6.64062 0 15 0C23.2812 0 30 6.71875 30 15C30 21.875 20.8594 33.9844 16.7969 39.0625C15.8594 40.2344 14.0625 40.2344 13.125 39.0625ZM15 20C17.7344 20 20 17.8125 20 15C20 12.2656 17.7344 10 15 10C12.1875 10 10 12.2656 10 15C10 17.8125 12.1875 20 15 20Z"
                            fill="#028835"
                          />
                        </svg>
                      </span>
                    </div>
                    <p
                      class="sm:text-[30px] font-semibold spline-sans sm:leading-[36px] text-2xl text-center text-primary-900 mb-3"
                    >
                      Address
                    </p>
                    <p
                      class="text-base leading-[27px] text-primary-100 text-center"
                    >
                      Dhaka 102, utl 1216, road 45 <br />
                      house of street
                    </p>
                    <div
                      class="w-[300px] h-[300px] rounded-full bg-primary-50 absolute left-[55px] bottom-[174px] xl:block hidden"
                    ></div>
                  </div>
                </div>
              </div>
            </div>
            <div
              data-aos="fade-up"
              data-aos-duration="1000"
              data-aos-delay="300"
              style="
                box-shadow: 0px 4.4px 12px -1px rgba(19, 16, 34, 0.06),
                  0px 2px 6.4px -1px rgba(19, 16, 34, 0.03);
              "
              class="item w-full"
            >
              <div
                class="w-full lg:h-[324px] h-[290px] relative overflow-hidden xl:bg-white bg-primary-50 rounded"
              >
                <div class="flex justify-center">
                  <div>
                    <div
                      class="mt-[50px] xl:mb-[90px] mb-10 flex justify-center relative z-10"
                    >
                      <span>
                        <svg
                          width="40"
                          height="30"
                          viewBox="0 0 40 30"
                          fill="none"
                          xmlns="http://www.w3.org/2000/svg"
                        >
                          <path
                            d="M36.25 0C38.2812 0 40 1.71875 40 3.75C40 5 39.375 6.09375 38.4375 6.79688L21.4844 19.5312C20.5469 20.2344 19.375 20.2344 18.4375 19.5312L1.48438 6.79688C0.546875 6.09375 0 5 0 3.75C0 1.71875 1.64062 0 3.75 0H36.25ZM16.9531 21.5625C18.75 22.8906 21.1719 22.8906 22.9688 21.5625L40 8.75V25C40 27.8125 37.7344 30 35 30H5C2.1875 30 0 27.8125 0 25V8.75L16.9531 21.5625Z"
                            fill="#028835"
                          />
                        </svg>
                      </span>
                    </div>
                    <p
                      class="sm:text-[30px] font-semibold spline-sans sm:leading-[36px] text-2xl text-center text-primary-900 mb-3"
                    >
                      E-mail
                    </p>
                    <p
                      class="text-base leading-[27px] text-primary-100 text-center"
                    >
                      an000@yourmail.com <br />
                      Suppport@emailhub.net.com
                    </p>
                    <div
                      class="w-[300px] h-[300px] rounded-full bg-primary-50 absolute left-[55px] bottom-[174px] xl:block hidden"
                    ></div>
                  </div>
                </div>
              </div>
            </div>
            <div
              data-aos="fade-up"
              data-aos-duration="1000"
              data-aos-delay="500"
              style="
                box-shadow: 0px 4.4px 12px -1px rgba(19, 16, 34, 0.06),
                  0px 2px 6.4px -1px rgba(19, 16, 34, 0.03);
              "
              class="item w-full"
            >
              <div
                class="w-full lg:h-[324px] h-[290px] relative overflow-hidden xl:bg-white bg-primary-50 rounded"
              >
                <div class="flex justify-center">
                  <div>
                    <div
                      class="mt-[50px] xl:mb-[90px] mb-10 flex justify-center relative z-10"
                    >
                      <span>
                        <svg
                          width="41"
                          height="42"
                          viewBox="0 0 41 42"
                          fill="none"
                          xmlns="http://www.w3.org/2000/svg"
                        >
                          <path
                            d="M39.9219 31.2344L38.0469 39.125C37.8125 40.2969 36.875 41.0781 35.7031 41.0781C16.0156 41 0 24.9844 0 5.29688C0 4.125 0.703125 3.1875 1.875 2.95312L9.76562 1.07812C10.8594 0.84375 12.0312 1.46875 12.5 2.48438L16.1719 11C16.5625 12.0156 16.3281 13.1875 15.4688 13.8125L11.25 17.25C13.9062 22.6406 18.2812 27.0156 23.75 29.6719L27.1875 25.4531C27.8125 24.6719 28.9844 24.3594 30 24.75L38.5156 28.4219C39.5312 28.9688 40.1562 30.1406 39.9219 31.2344Z"
                            fill="#028835"
                          />
                        </svg>
                      </span>
                    </div>
                    <p
                      class="sm:text-[30px] font-semibold spline-sans sm:leading-[36px] text-2xl text-center text-primary-900 mb-3"
                    >
                      Call us
                    </p>
                    <p
                      class="text-base leading-[27px] text-primary-100 text-center"
                    >
                      0000 - 000 - 000 00 <br />
                      +1234 - 000
                    </p>
                    <div
                      class="w-[300px] h-[300px] rounded-full bg-primary-50 absolute left-[55px] bottom-[174px] xl:block hidden"
                    ></div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>




	<?php 


	}
				

}

