<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_contact_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-home-contact-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Contact Section Two', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_contact', [
            'label' => esc_html__( 'Banner Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'sub-title', [
            'label'       => __( 'Sub Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section sub title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section description here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'form-content', [
            'label'       => __( 'Insert Form Shortcode', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::WYSIWYG,
            'default'     => __( 'Form Shortcode', 'kewi-extra' ),
            'description' => esc_html__( 'Enter form shortcode', 'kewi-extra' ),

        ] );





        $this->end_controls_section();


		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        extract($settings); 


		
		?>


        <section class="w-full custom-form-two-wrapper">
          <div class="theme-container mx-auto">
            <div class="grid lg:grid-cols-2 grid-cols-1 items-center">
              <div class="mb-10 lg:mb-0">
                <p
                  class="text-primary-500 font-bold lg:leading-8 spline-sans lg:text-xl text-lg uppercase mb-2"
                >
                  <?php echo wp_kses_post( $settings['sub-title'] ); ?>
                </p>
                <h2 class="headline-default text-primary-900 mb-[30px]">
                  <?php echo wp_kses_post( $settings['title'] ); ?>
                </h2>
                <p class="text-base leading-[27px] text-primary-100">
                  <?php echo wp_kses_post( $settings['description'] ); ?>
                </p>
              </div>
              <div class="w-full custom-form-two">


              	<?php echo $settings['form-content']; ?>

              </div>


            </div>
          </div>
        </section>


	<?php 


	}
				

}

