<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_contact extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-home-contact';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Contact Section', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_contact', [
            'label' => esc_html__( 'Banner Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'form-content', [
            'label'       => __( 'Insert Form Shortcode', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::WYSIWYG,
            'default'     => __( 'Form Shortcode', 'kewi-extra' ),
            'description' => esc_html__( 'Enter form shortcode', 'kewi-extra' ),

        ] );

        $this->add_control( 'feature_image_one', [
            'label'   => __( 'Choose Image Left', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'feature_image_two', [
            'label'   => __( 'Choose Image Right', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );




        $this->end_controls_section();


		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        extract($settings); 


		
		?>


            <!--get in touch-->
            <section class="getin-touch-wrapper w-full lg:py-[120px] py-[60px]">
                <div class="w-full relative">
                    <div class="w-full grid grid-cols-2 absolute">
                        <div class="img-1 w-full h-full">
                            <img
                                src="<?php echo esc_url( $settings['feature_image_one']['url'] ); ?>"
                                alt="thumb-1"
                                class="w-full h-full"
                                />
                        </div>
                        <div class="img-1 w-full h-full">
                            <img
                                src="<?php echo esc_url( $settings['feature_image_two']['url'] ); ?>"
                                alt="thumb-2"
                                class="w-full h-full"
                                />
                        </div>
                    </div>
                </div>
                <div
                    class="theme-container mx-auto relative z-10 lg:top-[120px] top-[60px]"
                    >
                    <div class="w-full flex xl:justify-end justify-center">
                        <div
                            class="sm:w-[630px] w-full sm:px-[60px] sm:py-[80px] px-5 py-8 rounded-[10px] bg-white relative xl:left-[35px] theme-home-form-padding"
                            style="box-shadow: 0px 16px 52px rgba(0, 0, 0, 0.07)"
                            >
                            <h2 class="headline-default text-primary-900 mb-10 font-bold home-form-title">

                                <?php echo wp_kses_post( $settings['title'] ); ?>

                            </h2>

                            <div class="w-full home-custom-form-wrapper">

                                <?php echo $settings['form-content']; ?>

                            </div>
                        </div>
                    </div>
                </div>
            </section>


	<?php 


	}
				

}

