<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_facts_faq_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-facts-faq-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Fun Facts & FAQs: 2', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_faqsec', [
            'label' => esc_html__( 'FAQs Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Insurance that goes', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'sub-title', [
            'label'       => __( 'Sub Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'ASK ANYTHING', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section sub title here.", 'insucom-extra' ),

        ] );


        $this->add_control( 'faqItems', [
            'label'       => esc_html__( 'FAQ Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'faq-title'        => esc_html__( 'How does the insurance slogan generator work?', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'faq-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'How does the insurance slogan generator work?', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'faq-des',
                    'label'       => esc_html__( 'Description', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Lorem ipsum dolor sit amet consectetur. Aliquam ullamcorper id pretium diam ame lacus.', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter description', 'insucom-extra' )
                ],
                
                

            ],
            'title_field' => "{{name}}"
        ] );

        $this->add_control( 'section_bg_image', [
            'label'   => __( 'Choose Bcakground Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'section_thumb_image', [
            'label'   => __( 'Choose FAQs Thum Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'abt_client_text', [
            'label'       => __( 'About Client Text', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type text here', 'insucom-extra' ),
            'default'     => __( 'Daily Activity', 'insucom-extra' ),
        ] );

        $this->add_control( 'abt_client_text2', [
            'label'       => __( 'About Client Text Bottom', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type text here', 'insucom-extra' ),
            'default'     => __( 'Loream is ispam', 'insucom-extra' ),
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_fun_fact_itemlist', [
            'label' => esc_html__( 'Fun Fact List', 'insucom-extra' ),
        ] ); 

        $this->add_control( 'factItems', [
            'label'       => esc_html__( 'Fun Fact Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'fact-title'        => esc_html__( 'Complete Projects', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'fact-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Complete Projects', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'fact-number',
                    'label'       => esc_html__( 'Enter Fact Number', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => __( '30K+', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Number', 'insucom-extra' )
                ],

                [
                    'name'        => 'fact-count',
                    'label'       => esc_html__( 'Enter Fact Number Count Text', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'K+', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter count text', 'insucom-extra' )
                ],


                [
                    'name'        => 'fact-image',
                    'label'       => esc_html__( 'Fact Counter Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload fact image', 'insucom-extra' )
                ],
                

            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $factItems = $settings['factItems'];
        $faqItems = $settings['faqItems'];

        extract($settings); 


		
		?>


      <!--      fun fact-->
      <section class="fun-fact-area-two relative" style="background-image:url(<?php echo esc_url( $settings['section_bg_image']['url'] ); ?>;)">
        <div class="w-full lg:py-[150px] py-[60px] sm:h-[748px] h-full">
          <div class="theme-container mx-auto relative">
            <div
              class="grid sm:grid-cols-4 grid-cols-1 sm:gap-[30px] gap-[60px]"
            >


            <?php
                foreach ( $factItems as $item ):
            ?>

              <div class="counter-item bg-white rounded flex justify-center items-center h-[150px] relative">
                <div>
                  <h2
                    class="font-bold spline-sans lg:text-[44px] lg:leading-[55px] text-2xl text-primary-900 text-center mb-1.5"
                  >
                    <span
                      class="purecounter"
                      data-purecounter-duration="1"
                      data-purecounter-end="<?php echo $item['fact-number'] ?>"
                    ></span
                    ><?php echo wp_kses_post( $item['fact-count'] ); ?>
                  </h2>
                  <p class="text-base text-primary-100"><?php echo wp_kses_post( $item['fact-title'] ); ?></p>
                </div>
                <div
                  style="left: calc(50% - 32px); bottom: calc(100% - 32px)"
                  class="w-[64px] h-[64px] rounded-full bg-primary-500 flex justify-center items-center absolute"
                >
                  <img src="<?php echo esc_url( $item['fact-image']['url'] ); ?>" alt="ico" />
                </div>
              </div>

          <?php endforeach; ?>


            </div>
          </div>
        </div>
      </section>
      <!--      faq section-->


      <!--      faq section-->
      <section class="faq-section-main-wrapper w-full lg:-mt-[327px] sm:-mt-[466px] my-[60px] relative z-10">
        <div class="theme-container mx-auto">
          <div
            data-aos="fade-up"
            data-aos-duration="1000"
            class="faq-two xl:w-[5000px] w-full bg-white sm:p-[60px] p-0 rounded-[10px] flex xl:flex-row flex-col xl:space-x-[75px] space-y-[75px] xl:space-y-0 xl:items-center"
          >
            <!--              fun fact thumb-->
            <div
              class="sm:w-[525px] w-full xl:h-[741px] h-[500px] relative rounded-[10px] overflow-hidden"
            >
              <img
                src="<?php echo esc_url( $settings['section_thumb_image']['url'] ); ?>"
                alt="thumb"
                class="w-full h-full object-cover"
              />
              <div
                class="w-[268px] h-[87px] rounded-full p-3 bg-white absolute right-5 bottom-5"
                style="
                  box-shadow: 0px 4.8px 24.4px -6px rgba(19, 16, 34, 0.1),
                    0px 4px 13px -2px rgba(19, 16, 34, 0.06);
                "
              >
                <div class="flex space-x-[15px] items-center">
                  <div
                    class="w-[63px] h-[63px] rounded-full bg-secondary flex justify-center items-center"
                  >
                    <svg
                      width="36"
                      height="36"
                      viewBox="0 0 36 36"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                    >
                      <path
                        d="M33.4049 19.0345C33.6025 27.8649 25.8057 35.6541 16.9828 35.4717C8.388 35.5173 0.993959 28.5033 0.560759 19.9161C-0.123241 10.7588 7.8028 2.39958 16.9752 2.59718C17.188 2.59718 17.3552 2.77198 17.3552 2.97718V18.6545H33.0325C33.2377 18.6545 33.4049 18.8217 33.4049 19.0345Z"
                        fill="#028835"
                      />
                      <path
                        d="M35.4816 16.9646C35.4816 17.1698 35.3144 17.337 35.1016 17.337H19.0443C18.8391 17.337 18.6719 17.1698 18.6719 16.9646V0.907344C18.6719 0.694544 18.8391 0.527344 19.0443 0.527344C28.1103 0.527344 35.4816 7.89858 35.4816 16.9646Z"
                        fill="#004C3F"
                      />
                    </svg>
                  </div>
                  <div>
                    <span class="text-base font-bold text-gray-700 block">
                      <?php echo $settings['abt_client_text'] ?></span
                    >
                    <span class="text-base text-gray-700 block"
                      ><?php echo $settings['abt_client_text2'] ?></span
                    >
                  </div>
                </div>
              </div>
            </div>
            <div>
              <p
                class="text-primary-500 font-bold sm:leading-8 spline-sans sm:text-xl text-md uppercase mb-2"
              >
                <?php echo wp_kses_post( $settings['sub-title'] ); ?>
              </p>
              <h2 class="headline-default faq-two-title-wrap text-primary-900 mb-[60px]">
                <?php echo wp_kses_post( $settings['title'] ); ?>
              </h2>
              <div class="xl:w-[570px] w-full flex flex-col space-y-5">


                <?php
                    foreach ( $faqItems as $item ):
                ?>


                <div
                  class="faq-item active sm:px-[30px] sm:py-5 p-3 w-full overflow-hidden rounded bg-secondary"
                >
                  <button
                    type="button"
                    class="faq-btn flex justify-between items-center w-full common-trans relative sm:text-center text-start"
                  >
                    <span
                      class="sm:text-lg text-sm spline-sans font-semibold group-hover:text-white"
                      ><?php echo wp_kses_post( $item['faq-title'] ); ?></span
                    >
                    <span
                      class="flex justify-center items-center sm:w-[47px] sm:h-[47px] w-8 h-8 bg-primary-500 text-white rounded absolute -right-3 sm:-right-6 sm:-top-3.5 -top-3"
                    >
                      <svg
                        width="12"
                        height="17"
                        viewBox="0 0 12 17"
                        fill="none"
                        xmlns="http://www.w3.org/2000/svg"
                        class="fill-current"
                      >
                        <path
                          d="M5.28125 15.6875L1.28125 11.6875C0.875 11.3125 0.875 10.6562 1.28125 10.2812C1.65625 9.875 2.3125 9.875 2.6875 10.2812L5 12.5625L5 1C5 0.4375 5.4375 0 6 0C6.59375 0 7 0.4375 7 1L7 12.5625L9.28125 10.2812C9.65625 9.875 10.3125 9.875 10.6875 10.2812C11.0937 10.6562 11.0937 11.3125 10.6875 11.6875L6.6875 15.6875C6.3125 16.0938 5.65625 16.0938 5.28125 15.6875Z"
                        />
                      </svg>
                    </span>
                  </button>
                  <div class="faq-body w-full bg-secondary">
                    <p
                      class="sm:text-base text-sm sm:leading-7 text-primary-100"
                    >
                      <?php echo wp_kses_post( $item['faq-des'] ); ?>

                    </p>
                  </div>
                </div>

                <?php endforeach; ?>




              </div>
            </div>
          </div>
        </div>
      </section>



	<?php 


	}
				

}

