<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_facts_faq extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-facts-faq-sec';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Fun Facts & FAQs', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_faqsec', [
            'label' => esc_html__( 'FAQs Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );


        $this->add_control( 'faqItems', [
            'label'       => esc_html__( 'FAQ Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'faq-title'        => esc_html__( 'How does the insurance slogan generator work?', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'faq-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'How does the insurance slogan generator work?', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'faq-des',
                    'label'       => esc_html__( 'Description', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Lorem ipsum dolor sit amet consectetur. Aliquam ullamcorper id pretium diam ame lacus.', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter description', 'insucom-extra' )
                ],
                
                

            ],
            'title_field' => "{{name}}"
        ] );

        $this->add_control( 'section_bg_image', [
            'label'   => __( 'Choose Bcakground Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'section_thumb_image', [
            'label'   => __( 'Choose FAQs Thum Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_fun_fact_itemlist', [
            'label' => esc_html__( 'Fun Fact List', 'insucom-extra' ),
        ] ); 

        $this->add_control( 'factItems', [
            'label'       => esc_html__( 'Fun Fact Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'fact-title'        => esc_html__( 'Complete Projects', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'fact-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Complete Projects', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'fact-number',
                    'label'       => esc_html__( 'Enter Fact Number', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => __( '30K+', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Number', 'insucom-extra' )
                ],

                [
                    'name'        => 'fact-count',
                    'label'       => esc_html__( 'Enter Fact Number Count Text', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'K+', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter count text', 'insucom-extra' )
                ],


                [
                    'name'        => 'fact-image',
                    'label'       => esc_html__( 'Fact Counter Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload fact image', 'insucom-extra' )
                ],
                

            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $factItems = $settings['factItems'];
        $faqItems = $settings['faqItems'];

        extract($settings); 


		
		?>


            <!--      fun fact-->
            <section
                class="fun-fact-area theme-custom-faq-area lg:pt-[120px] xl:pb-0 lg:pb-[120px] py-[60px] xl:min-h-[1000px]"
                style="
                background-image: url(<?php echo esc_url( $settings['section_bg_image']['url'] ); ?>);
                background-repeat: no-repeat;
                background-size: cover;
                "
                >
                <div class="theme-container mx-auto relative">
                    <div
                        class="w-full flex flex-wrap lg:flex-nowrap gap-[30px] lg:gap-0 justify-between items-center xl:mb-[100px] lg:mb-[60px] mb-[30px] custom-fun-fact-wrap"
                        >

                        <?php
                            foreach ( $factItems as $item ):
                        ?>


                        <div class="item flex space-x-5 items-center">
                            <div
                                class="xl:w-[80px] xl:h-[80px] w-16 h-16 rounded-full bg-primary-500 flex justify-center items-center"
                                >
                                <img src="<?php echo esc_url( $item['fact-image']['url'] ); ?>" alt="" />
                            </div>
                            <div class="flex-1">
                                <p
                                    class="xl:text-[40px] font-bold text-white text-2xl xl:leading-[55px]"
                                    >
                                    <span
                                        class="purecounter"
                                        data-purecounter-duration="1"
                                        data-purecounter-end="<?php echo $item['fact-number'] ?>"
                                        ></span
                                        ><?php echo wp_kses_post( $item['fact-count'] ); ?>
                                </p>
                                <p class="xl:text-base text-sm text-white leading-7">
                                    <?php echo wp_kses_post( $item['fact-title'] ); ?>
                                </p>
                            </div>
                        </div>
                        <div class="w-[5px] h-[160px] bg-[#1A5E52] xl:block hidden"></div>

                        <?php endforeach; ?> 



                    </div>
                    <div class="faq-wrapper w-full xl:absolute xl:flex items-center">
                        <div class="w-[740px] xl:block hidden rounded-[10px]">
                            <div class="w-full h-[888px]">
                                <img
                                    src="<?php echo esc_url( $settings['section_thumb_image']['url'] ); ?>"
                                    alt=""
                                    class="w-full h-full object-cover"
                                    />
                            </div>
                        </div>
                        <div class="flex-1">
                            <div
                                data-aos="fade-up"
                                data-aos-duration="1000"
                                class="faq-main-wrapper xl:w-[630px] sm:px-[60px] sm:py-[80px] px-3 py-10 bg-white rounded xl:absolute top-20 xl:right-10"
                                >
                                <h2 class="headline-default text-primary-900 mb-[42px]">
                                    <?php echo wp_kses_post( $settings['title'] ); ?>
                                </h2>
                                <div class="w-full flex flex-col space-y-5">

                                <?php
                                    foreach ( $faqItems as $item ):
                                ?>

                                    <div
                                        class="faq-item active w-full overflow-hidden rounded border border-primaryBorder"
                                        >
                                        <button
                                            type="button"
                                            class="faq-btn p-5 flex justify-between group hover:bg-primary-500 items-center w-full common-trans sm:text-center text-start"
                                            >
                                            <span
                                                class="sm:text-lg text-sm spline-sans font-semibold group-hover:text-white"
                                                ><?php echo wp_kses_post( $item['faq-title'] ); ?></span
                                                >
                                            <span class="group-hover:text-white">
                                                <svg
                                                    width="14"
                                                    height="9"
                                                    viewBox="0 0 14 9"
                                                    fill="none"
                                                    xmlns="http://www.w3.org/2000/svg"
                                                    class="fill-current"
                                                    >
                                                    <path
                                                        d="M7.6875 7.6875C7.3125 8.09375 6.65625 8.09375 6.28125 7.6875L1.28125 2.6875C0.875 2.3125 0.875 1.65625 1.28125 1.28125C1.65625 0.875 2.3125 0.875 2.6875 1.28125L7 5.5625L11.2812 1.28125C11.6562 0.875 12.3125 0.875 12.6875 1.28125C13.0938 1.65625 13.0938 2.3125 12.6875 2.6875L7.6875 7.6875Z"
                                                        />
                                                </svg>
                                            </span>
                                        </button>
                                        <div class="faq-body w-full bg-secondary">
                                            <p
                                                class="sm:text-base text-sm leading-7 text-primary-100"
                                                >
                                                <?php echo wp_kses_post( $item['faq-des'] ); ?>
                                            </p>
                                        </div>
                                    </div>

                                    <?php endforeach; ?> 



                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>



	<?php 


	}
				

}

