<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_features_tab extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-features-tab-sec';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Features Tab', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_ftabsec', [
            'label' => esc_html__( 'Tab Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'tab_1', [
            'label'       => __( 'Tab Menu 1', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Monthly', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type tab menu name 1.", 'insucom-extra' ),

        ] );

        $this->add_control( 'tab_2', [
            'label'       => __( 'Tab Menu 2', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Show All', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type tab menu name 2.", 'insucom-extra' ),

        ] );

        $this->add_control( 'tab_3', [
            'label'       => __( 'Tab Menu 3', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Yearly', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type tab menu name 3.", 'insucom-extra' ),

        ] );


        $this->add_control( 'tabItems1', [
            'label'       => esc_html__( 'Tab Single Item 1st', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'tab-title'        => esc_html__( 'Coverage Pro', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'tab-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Coverage Pro', 'insucom-extra' ),
                    'description' => esc_html__( 'Feature Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'tab-image',
                    'label'       => esc_html__( 'Feature Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload client image', 'insucom-extra' )
                ],

                
                

            ],
            'title_field' => "{{name}}"
        ] );

         $this->add_control( 'tabItems2', [
            'label'       => esc_html__( 'Tab Single Item 2nd', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'tab-title'        => esc_html__( 'Securely', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'tab-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Coverage Pro', 'insucom-extra' ),
                    'description' => esc_html__( 'Feature Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'tab-image',
                    'label'       => esc_html__( 'Feature Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload client image', 'insucom-extra' )
                ],

                
                

            ],
            'title_field' => "{{name}}"
        ] );


        $this->add_control( 'tabItems3', [
            'label'       => esc_html__( 'Tab Single Item 3rd', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'tab-title'        => esc_html__( 'Risk Proof', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'tab-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Coverage Pro', 'insucom-extra' ),
                    'description' => esc_html__( 'Feature Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'tab-image',
                    'label'       => esc_html__( 'Feature Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload client image', 'insucom-extra' )
                ],

                
                

            ],
            'title_field' => "{{name}}"
        ] );

        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $tabItems1 = $settings['tabItems1'];
        $tabItems2 = $settings['tabItems2'];
        $tabItems3 = $settings['tabItems3'];


        extract($settings); 


		
		?>


      <!--    safety section-->
      <section class="safety-section w-full lg:py-[120px] py-[60px]">
        <div class="theme-container mx-auto">
          <h2 class="headline-default text-primary-900 mb-[30px] text-center">
            <?php echo wp_kses_post( $settings['title'] ); ?>
          </h2>
          <div class="flex justify-center mb-[60px]">
            <div class="tab flex sm:space-x-[30px] space-x-3.5 items-center">

              <button
                onclick="openPriority(event, 'all')"
                type="button"
                class="filter-btn sm:px-5 sm:py-2.5 py-1.5 px-2 rounded-[10px] sm:text-base text-sm spline-sans font-semibold hover:bg-primary-500 hover:text-white active"
              >
                <?php echo $settings['tab_1'] ?>
              </button>

              <button
                onclick="openPriority(event, 'month')"
                type="button"
                class="filter-btn sm:px-5 sm:py-2.5 py-1.5 px-2 rounded-[10px] sm:text-base text-sm spline-sans font-semibold hover:bg-primary-500 hover:text-white"
              >
                <?php echo $settings['tab_2'] ?>
              </button>

              <button
                onclick="openPriority(event, 'year')"
                type="button"
                class="filter-btn sm:px-5 sm:py-2.5 py-1.5 px-2 rounded-[10px] sm:text-base text-sm spline-sans font-semibold hover:bg-primary-500 hover:text-white"
              >
               <?php echo $settings['tab_3'] ?>
              </button>

            </div>
          </div>


          <div id="all" class="blog-content active">
            <div
              class="grid lg:grid-cols-3 sm:grid-cols-2 grid-cols-1 lg:gap-[30px] gap-y-[60px] gap-x-[30px]"
            >


            <?php
                foreach ( $tabItems1 as $item ):
            ?>

              <div class="w-full relative group">
                <!--                thumb-->
                <div class="w-full h-[440px] rounded overflow-hidden">
                  <img
                    src="<?php echo esc_url( $item['tab-image']['url'] ); ?>"
                    class="w-full h-full object-cover"
                    alt="blog"
                  />
                </div>
                <div class="w-full px-10 absolute -bottom-[34px]">
                  <div
                    style="box-shadow: 0 0 60px rgba(0, 0, 0, 0.05)"
                    class="w-full h-[68px] bg-white rounded flex justify-center items-center group-hover:bg-primary-500 common-trans"
                  >
                    <span
                      class="text-lg font-bold spline-sans group-hover:text-white text-primary-900 common-trans"
                      ><?php echo wp_kses_post( $item['tab-title'] ); ?></span
                    >
                  </div>
                </div>
              </div>

            <?php endforeach; ?>


            </div>
          </div>


          <div id="month" class="blog-content">
            <div
              class="grid lg:grid-cols-3 sm:grid-cols-2 grid-cols-1 lg:gap-[30px] gap-y-[60px] gap-x-[30px]"
            >


            <?php
                foreach ( $tabItems2 as $item ):
            ?>

              <div class="w-full relative group">
                <!--                thumb-->
                <div class="w-full h-[440px] rounded overflow-hidden">
                  <img
                    src="<?php echo esc_url( $item['tab-image']['url'] ); ?>"
                    class="w-full h-full object-cover"
                    alt="blog"
                  />
                </div>
                <div class="w-full px-10 absolute -bottom-[34px]">
                  <div
                    style="box-shadow: 0 0 60px rgba(0, 0, 0, 0.05)"
                    class="w-full h-[68px] bg-white rounded flex justify-center items-center group-hover:bg-primary-500 common-trans"
                  >
                    <span
                      class="text-lg font-bold spline-sans group-hover:text-white text-primary-900 common-trans"
                      ><?php echo wp_kses_post( $item['tab-title'] ); ?></span
                    >
                  </div>
                </div>
              </div>

            <?php endforeach; ?>




            </div>
          </div>

          <div id="year" class="blog-content">
            <div
              class="grid lg:grid-cols-3 sm:grid-cols-2 grid-cols-1 lg:gap-[30px] gap-y-[60px] gap-x-[30px]"
            >


            <?php
                foreach ( $tabItems3 as $item ):
            ?>

              <div class="w-full relative group">
                <!--                thumb-->
                <div class="w-full h-[440px] rounded overflow-hidden">
                  <img
                    src="<?php echo esc_url( $item['tab-image']['url'] ); ?>"
                    class="w-full h-full object-cover"
                    alt="blog"
                  />
                </div>
                <div class="w-full px-10 absolute -bottom-[34px]">
                  <div
                    style="box-shadow: 0 0 60px rgba(0, 0, 0, 0.05)"
                    class="w-full h-[68px] bg-white rounded flex justify-center items-center group-hover:bg-primary-500 common-trans"
                  >
                    <span
                      class="text-lg font-bold spline-sans group-hover:text-white text-primary-900 common-trans"
                      ><?php echo wp_kses_post( $item['tab-title'] ); ?></span
                    >
                  </div>
                </div>
              </div>

            <?php endforeach; ?>


            </div>
          </div>


        </div>
      </section>



	<?php 


	}
				

}

