<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_insurance_slider extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-insurance-slide';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Insurance Slider', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_services', [
            'label' => esc_html__( 'Section Title', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );



        $this->end_controls_section();


        $this->start_controls_section( 'section_content_insuslide_fitemlist', [
            'label' => esc_html__( 'Slide Item List', 'insucom-extra' ),
        ] ); 

        $this->add_control( 'insItems', [
            'label'       => esc_html__( 'Slide Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'slide-title'        => esc_html__( 'Rock Solid Insurance', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'slide-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Rock Solid Insurance', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],


                [
                    'name'        => 'slide-image',
                    'label'       => esc_html__( 'Slide Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload service image', 'insucom-extra' )
                ],
                

                [
                    'name'        => 'slide_btn_link',
                    'label'       => esc_html__( 'Slide Button Link', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],


            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $insItems = $settings['insItems'];

        extract($settings); 


		
		?>



<!-- life insurence-->
<section
   class="life-insu-area w-full lg:py-[120px] pt-[60px] pb-[100px] overflow-hidden"
   >
   <div class="text-center">
      <h2 class="headline-default text-primary-900 lg:mb-[60px] mb-[30px]">
         
         <?php echo wp_kses_post( $settings['title'] ); ?>

      </h2>
      <div class="insu-swiper relative">
         <div class="swiper-wrapper">

            <?php
                foreach ( $insItems as $item ):
            ?>

            <div class="swiper-slide">
               <div
                  class="w-full lg:h-[550px] h-[300px] flex justify-center items-center group"
                  style="
                  background-image: url(<?php echo esc_url( $item['slide-image']['url'] ); ?>);
                  background-size: cover;
                  background-repeat: no-repeat;
                  "
                  >
                  <a href="<?php echo esc_url( $item['slide_btn_link']['url'] ) ?>">
                     <div
                        class="px-[30px] py-[20px] bg-primary-500 rounded text-lg spline-sans font-semibold text-white opacity-0 group-hover:opacity-100 common-trans"
                        >
                        <?php echo wp_kses_post( $item['slide-title'] ); ?>
                     </div>
                  </a>
               </div>
            </div>

            <?php endforeach; ?> 


         </div>
         <div class="swiper-pagination"></div>
      </div>
   </div>
</section>



	<?php 


	}
				

}

