<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_about_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-about-one';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home About:1', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_about1', [
            'label' => esc_html__( 'About Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'IWhat ets us apart from the rest is our visionary', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type sbanner short description here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'qualityItems', [
            'label'       => esc_html__( 'Quality Single Item', 'kewi-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'quality-title'        => esc_html__( 'Fast Response Insurance', 'kewi-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'quality-title',
                    'label'       => esc_html__( 'Title', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Fast Response Insurance', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Title', 'kewi-extra' )
                ],


                [
                    'name'        => 'quality-number',
                    'label'       => esc_html__( 'Quality Number', 'kewi-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( '95', 'kewi-extra' ),
                    'description' => esc_html__( 'Enter Number', 'kewi-extra' )
                ],



            ],
            'title_field' => "{{name}}"
        ] );


        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );



        $this->end_controls_section();


        $this->start_controls_section( 'section_content_about_inner_img', [
            'label' => esc_html__( 'About Image Section', 'insucom-extra' ),
        ] ); 


        $this->add_control( 'about_feature_image', [
            'label'   => __( 'Choose About Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control( 'client_number', [
            'label'       => __( 'Client Number', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type number here', 'insucom-extra' ),
            'default'     => __( '5000+', 'insucom-extra' ),
        ] );

        $this->add_control( 'client_text', [
            'label'       => __( 'Client Text', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type text here', 'insucom-extra' ),
            'default'     => __( 'Satisfied Client', 'insucom-extra' ),
        ] );
        
    

        $this->end_controls_section();



		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();
        $qualityItems = $settings['qualityItems'];

        extract($settings); 


		
		?>


            <!--      about-->
            <section class="about-area theme-custom-about-one w-full lg:py-[120px] py-[60px]">
                <div class="theme-container mx-auto">
                    <div
                        class="w-full grid xl:grid-cols-2 grid-cols-1 lg:gap-[66px] gap-[30px] items-center relative"
                        >
                        <div class="">
                            <div
                                class="thumbnail-area 2xl:w-[721px] w-full 2xl:absolute 2xl:-left-[150px] -top-8 relative"
                                >
                                <img
                                    src="<?php echo esc_url( $settings['about_feature_image']['url'] ); ?>"
                                    alt="about"
                                    class="relative z-10 w-full h-full"
                                    />
                                <div
                                    class="about-shape gear-2 xl:w-[385px] xl:h-[385px] md:w-[500px] md:h-[500px] w-[250px] h-[250px]"
                                    ></div>
                                <div
                                    class="w-[250px] h-[94px] rounded-[16px] bg-primary-500 flex justify-center items-center absolute sm:top-[432px] top-[200px] sm:right-[156px] right-5 z-10"
                                    >
                                    <div>
                                        <div class="flex space-x-6 items-center">
                                            <span>
                                                <svg
                                                    width="40"
                                                    height="40"
                                                    viewBox="0 0 40 40"
                                                    fill="none"
                                                    xmlns="http://www.w3.org/2000/svg"
                                                    >
                                                    <circle cx="20" cy="20" r="20" fill="white" />
                                                    <path
                                                        d="M26.332 25.7943C25.544 25.5133 24.258 25.4943 23.688 25.2813C23.2492 25.1672 22.8347 24.974 22.465 24.7113C22.3097 24.0566 22.2424 23.3839 22.265 22.7113C22.558 22.4302 22.7955 22.0964 22.965 21.7273C23.1351 21.0941 23.2479 20.4468 23.302 19.7933C23.302 19.7933 23.766 19.9933 23.949 19.0623C24.104 18.2623 24.399 17.8393 24.322 17.2483C24.245 16.6573 23.914 16.7983 23.914 16.7983C24.273 15.9711 24.4135 15.0655 24.322 14.1683C24.3166 13.591 24.1924 13.0209 23.9571 12.4935C23.7218 11.9662 23.3806 11.493 22.9545 11.1032C22.5285 10.7135 22.0268 10.4156 21.4806 10.2281C20.9345 10.0406 20.3556 9.96749 19.78 10.0133C19.2044 9.96746 18.6254 10.0402 18.0789 10.227C17.5324 10.4138 17.0301 10.7107 16.603 11.0994C16.1758 11.4881 15.833 11.9603 15.5956 12.4868C15.3583 13.0133 15.2315 13.5829 15.223 14.1603C15.1325 15.0567 15.2701 15.9614 15.623 16.7903C15.623 16.7903 15.293 16.6493 15.215 17.2403C15.137 17.8313 15.427 18.2603 15.586 19.0603C15.769 19.9953 16.233 19.7913 16.233 19.7913C16.2878 20.4447 16.4005 21.092 16.57 21.7253C16.7396 22.0944 16.9771 22.4282 17.27 22.7093C17.2927 23.3819 17.2254 24.0546 17.07 24.7093C16.7014 24.9723 16.2865 25.1633 15.847 25.2723C15.285 25.4903 13.998 25.5183 13.203 25.7993C12.2445 26.1586 11.4205 26.8055 10.844 27.6514C10.2676 28.4973 9.96683 29.5008 9.98304 30.5243H29.545C29.5643 29.5005 29.2656 28.4958 28.6902 27.6487C28.1148 26.8017 27.2909 26.1538 26.332 25.7943Z"
                                                        fill="#028835"
                                                        />
                                                    <path
                                                        d="M11.63 22.3684C12.4561 22.3573 13.2651 22.132 13.978 21.7144C12.888 20.0624 13.478 18.1354 13.254 16.3354C13.243 15.9259 13.1472 15.5231 12.9728 15.1524C12.7983 14.7817 12.549 14.4511 12.2405 14.1816C11.9319 13.912 11.5709 13.7093 11.1801 13.5862C10.7894 13.4631 10.3773 13.4224 9.97 13.4664H9.942C9.53708 13.428 9.12858 13.4729 8.74171 13.5985C8.35485 13.7241 7.99783 13.9276 7.69271 14.1966C7.38758 14.4655 7.14083 14.7942 6.96768 15.1622C6.79453 15.5303 6.69866 15.9299 6.686 16.3364C6.461 18.1294 7.086 20.2744 5.969 21.7154C6.68409 22.1261 7.49988 22.3284 8.324 22.2994C8.36668 22.6942 8.34302 23.0934 8.254 23.4804C8.01199 23.682 7.72069 23.8156 7.41 23.8674C6.79373 24.0008 6.18571 24.1697 5.589 24.3734C5.1109 24.6233 4.71018 24.999 4.43013 25.4601C4.15007 25.9212 4.00134 26.45 4 26.9894H9.647C10.1603 26.0724 10.9468 25.3383 11.897 24.8894C12.4477 24.6587 13.0371 24.5345 13.634 24.5234C13.634 24.5234 13.901 24.1014 13.022 23.9394C12.5548 23.8369 12.1016 23.6787 11.672 23.4684C11.538 23.3184 11.63 22.3684 11.63 22.3684Z"
                                                        fill="#028835"
                                                        />
                                                    <path
                                                        d="M27.9417 22.3684C27.1157 22.3573 26.3066 22.132 25.5938 21.7144C26.6838 20.0624 26.0937 18.1354 26.3177 16.3354C26.3288 15.9259 26.4245 15.5231 26.599 15.1524C26.7734 14.7817 27.0227 14.4511 27.3313 14.1816C27.6398 13.912 28.0009 13.7093 28.3916 13.5862C28.7824 13.4631 29.1944 13.4224 29.6017 13.4664H29.6297C30.0347 13.428 30.4432 13.4729 30.83 13.5985C31.2169 13.7241 31.5739 13.9276 31.879 14.1966C32.1842 14.4655 32.4309 14.7942 32.6041 15.1622C32.7772 15.5303 32.8731 15.9299 32.8857 16.3364C33.1107 18.1294 32.4857 20.2744 33.6027 21.7154C32.8877 22.1261 32.0719 22.3284 31.2477 22.2994C31.2051 22.6942 31.2287 23.0934 31.3177 23.4804C31.5598 23.682 31.8511 23.8156 32.1617 23.8674C32.778 24.0008 33.386 24.1697 33.9827 24.3734C34.4608 24.6233 34.8616 24.999 35.1416 25.4601C35.4217 25.9212 35.5704 26.45 35.5717 26.9894H29.9247C29.4115 26.0724 28.6249 25.3383 27.6747 24.8894C27.1241 24.6587 26.5347 24.5345 25.9377 24.5234C25.9377 24.5234 25.6707 24.1014 26.5497 23.9394C27.0169 23.8369 27.4702 23.6787 27.8997 23.4684C28.0337 23.3184 27.9417 22.3684 27.9417 22.3684Z"
                                                        fill="#028835"
                                                        />
                                                </svg>
                                            </span>
                                            <div>
                                                <p class="text-white text-xl font-bold leading-[26px]">
                                                    <?php echo $settings['client_number'] ?>
                                                </p>
                                                <p class="text-base leading-5 text-white">
                                                    <?php echo $settings['client_text'] ?>
                                                </p>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="about-article-area">
                            <h2 class="headline-default text-primary-900 mb-10">
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </h2>
                            <div
                                class="xl:w-full max-w-4xl sm:p-[30px] p-5 border border-primaryBorder rounded-[10px] flex flex-col space-y-5 mb-5"
                                >

                        <?php
                            foreach ( $qualityItems as $item ):
                        ?>

                                <div class="item sm:flex sm:space-x-5 sm:items-center">

                                    <div
                                        class="w-[60px] h-[60px] bg-primary-50 sm:flex hidden justify-center items-center rounded"
                                        >
                                        <span>
                                            <svg
                                                width="18"
                                                height="13"
                                                viewBox="0 0 18 13"
                                                fill="none"
                                                xmlns="http://www.w3.org/2000/svg"
                                                >
                                                <path
                                                    d="M17.3594 0.640625C17.8672 1.10938 17.8672 1.92969 17.3594 2.39844L7.35938 12.3984C6.89062 12.9062 6.07031 12.9062 5.60156 12.3984L0.601562 7.39844C0.09375 6.92969 0.09375 6.10938 0.601562 5.64062C1.07031 5.13281 1.89062 5.13281 2.35938 5.64062L6.5 9.74219L15.6016 0.640625C16.0703 0.132812 16.8906 0.132812 17.3594 0.640625Z"
                                                    fill="#028835"
                                                    />
                                            </svg>
                                        </span>
                                    </div>
                                    <div class="flex-1">
                                        <div class="flex justify-between items-center mb-2.5">
                                            <span class="text-lg text-gray-900 font-bold spline-sans"
                                                ><?php echo wp_kses_post( $item['quality-title'] ); ?></span
                                                >
                                            <span class="text-lg text-gray-900 font-bold spline-sans"
                                                ><?php echo wp_kses_post( $item['quality-number'] ); ?>%</span
                                                >
                                        </div>
                                        <div
                                            class="w-full relative overflow-hidden h-[5px] rounded-[10px] bg-gray-100"
                                            >
                                            <div
                                                style="width: <?php echo wp_kses_post( $item['quality-number'] ); ?>%"
                                                class="absolute left-0 top-0 bg-primary-500 h-full rounded-[10px]"
                                                ></div>
                                        </div>
                                    </div>
                                </div>

                        <?php endforeach; ?> 


                            </div>

                            <p class="xl:w-full max-w-4xl text-base text-primary-100 mb-14 about-text-one">
                                <?php echo wp_kses_post( $settings['description'] ); ?>
                            </p>

                            <div>
                                <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>">
                                    <div
                                        class="px-[42px] py-[23px] bg-primary-500 hover:bg-primary-900 common-trans rounded-lg inline"
                                        >
                                        <span class="text-lg text-white"><?php echo $settings['btn_text'] ?></span>
                                    </div>
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </section>


	<?php 


	}
				

}

