<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_process extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-process-sec';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Process', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_servicestwo', [
            'label' => esc_html__( 'Section Title', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_process_itemlist', [
            'label' => esc_html__( 'Services Item List', 'insucom-extra' ),
        ] ); 

        $this->add_control( 'serviceItems', [
            'label'       => esc_html__( 'Service Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'service-title'        => esc_html__( 'Rock Solid Insurance', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'service-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Rock Solid Insurance', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'service-count',
                    'label'       => esc_html__( 'Number', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( '01', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Count Number', 'insucom-extra' )
                ],

                [
                    'name'        => 'service-des',
                    'label'       => esc_html__( 'Short Description', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'insucom-extra' )
                ],


                [
                    'name'        => 'service-image',
                    'label'       => esc_html__( 'Service Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload service image', 'insucom-extra' )
                ],
                


            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $serviceItems = $settings['serviceItems'];

        extract($settings); 


		
		?>


      <!--      process section-->
      <section class="process-section-two theme-custom-process w-full lg:py-[120px] py-[60px]">
        <div class="theme-container mx-auto">
          <div class="w-full relative">
            <h2 class="headline-default text-primary-900 mb-[60px] text-center">
               <?php echo wp_kses_post( $settings['title'] ); ?>
            </h2>
            <div
              class="grid xl:grid-cols-4 sm:grid-cols-2 grid-cols-1 gap-[30px]"
            >

            <?php
                foreach ( $serviceItems as $item ):
            ?>

              <div
                data-aos="fade-up"
                data-aos-duration="1000"
                data-aos-delay="100"
                class="item group px-[30px] py-10 rounded border border-primaryBorder relative overflow-hidden"
              >
                <div
                  class="icon-thumb flex justify-center mt-2.5 mb-[90px] relative z-10"
                >
                  <img
                    src="<?php echo esc_url( $item['service-image']['url'] ); ?>"
                    alt=""
                    class="w-[62px] h-[62px]"
                  />
                </div>
                <p
                  class="text-lg font-semibold spline-sans text-center text-[#E3E3E3] mb-5"
                >
                <?php echo wp_kses_post( $item['service-count'] ); ?>
                </p>
                <p
                  class="text-lg font-bold spline-sans text-center text-primary-900 mb-5"
                >
                  <?php echo wp_kses_post( $item['service-title'] ); ?>
                </p>
                <p class="text-primary-100 text-base text-center">
                  <?php echo wp_kses_post( $item['service-des'] ); ?>
                </p>
                <div
                  style="left: calc(50% - 185px)"
                  class="circle-shape group-hover:w-full group-hover:h-full w-[372px] h-[372px] rounded-full absolute bottom-[237px]"
                ></div>
              </div>

               <?php endforeach; ?> 



            </div>
          </div>
        </div>
      </section>



	<?php 


	}
				

}

