<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_services_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-services-onee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home Services: 01', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_services', [
            'label' => esc_html__( 'Section Title', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type sbanner short description here.", 'insucom-extra' ),

        ] );


        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'insucom-extra' ),
            'default'     => __( 'Read More', 'insucom-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );


        $this->add_control( 'section_bg_image', [
            'label'   => __( 'Choose Bcakground Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_services_fitemlist', [
            'label' => esc_html__( 'Services Item List', 'insucom-extra' ),
        ] ); 

        $this->add_control( 'serviceItems', [
            'label'       => esc_html__( 'Service Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'service-title'        => esc_html__( 'Rock Solid Insurance', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'service-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Rock Solid Insurance', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'service-des',
                    'label'       => esc_html__( 'Short Description', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'insucom-extra' )
                ],


                [
                    'name'        => 'service-image',
                    'label'       => esc_html__( 'Service Image', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => \Elementor\Utils::get_placeholder_image_src(),
                    ],

                    'description' => esc_html__( 'Upload service image', 'insucom-extra' )
                ],
                

                [
                    'name'        => 'service_btn_link',
                    'label'       => esc_html__( 'Service Button Link', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
                    'default'     => [
                        'url' => '#',
                    ],
                ],


            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $serviceItems = $settings['serviceItems'];

        extract($settings); 


		
		?>


            <!--service-->
            <section class="service-area theme-home-service-one w-full lg:py-[120px] py-[60px]" style="background-image:url(<?php echo esc_url( $settings['section_bg_image']['url'] ); ?>;)">
                <div class="theme-container mx-auto h-full items-center">
                    <div
                        class="w-full grid xl:grid-cols-2 grid-cols-1 gap-[60px] xl:gap-0 items-center"
                        >
                        <div class="grid-item">
                            <h2 class="headline-default text-primary-900 mb-5">
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </h2>
                            <p class="text-base text-primary-100 mb-14">
                                <?php echo wp_kses_post( $settings['description'] ); ?>
                            </p>
                            <div>
                                <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>">
                                    <div
                                        class="px-[42px] py-[23px] bg-primary-500 hover:bg-primary-900 common-trans rounded-lg inline"
                                        >
                                        <span class="text-lg text-white"><?php echo $settings['btn_text'] ?></span>
                                    </div>
                                </a>
                            </div>
                        </div>

                        <div class="grid-item">

                            <div class="grid sm:grid-cols-2 grid-cols-1 sm:gap-[30px] gap-5">

                                <?php
                                foreach ( $serviceItems as $item ):
                                ?>

                                <div
                                    data-aos="fade-up"
                                    data-aos-duration="1000"
                                    class="service-item p-[30px] rounded-[10px] bg-white group"
                                    >
                                    <a href="<?php echo esc_url( $item['service_btn_link']['url'] ) ?>">
                                        <div class="flex justify-center mb-5">
                                            <div
                                                class="w-[60px] h-[60px] rounded flex justify-center items-center bg-primary-50"
                                                >
                                                <img src="<?php echo esc_url( $item['service-image']['url'] ); ?>" alt="img">
                                            </div>
                                        </div>
                                        <h2
                                            class="text-lg leading-7 font-bold spline-sans text-center text-primary-900 mb-5 group-hover:underline"
                                            >
                                            <?php echo wp_kses_post( $item['service-title'] ); ?>
                                        </h2>
                                        <p class="text-base leading-7 text-center text-primary-100">
                                            <?php echo wp_kses_post( $item['service-des'] ); ?>
                                        </p>
                                    </a>
                                </div>

                                <?php endforeach; ?>  


                            </div>
                        </div>
                    </div>
                </div>
            </section>




	<?php 


	}
				

}

