<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_services_sbox extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-services-sbox';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Services Conetnt Box', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_servicebox', [
            'label' => esc_html__( 'Section Title', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Sub Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Invest in Startup', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section sub title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'sub-title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'What we offer', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description1', [
            'label'       => __( 'Description 1', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type short description 1 here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description2', [
            'label'       => __( 'Description 2', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type short description 2 here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description3', [
            'label'       => __( 'Description 3', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type short description 3 here.", 'insucom-extra' ),

        ] );



        $this->add_control( 'section_right_image', [
            'label'   => __( 'Choose Image', 'kewi-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->end_controls_section();


        $this->start_controls_section( 'section_content_process_bxlist', [
            'label' => esc_html__( 'Services Item List', 'insucom-extra' ),
        ] ); 

        $this->add_control( 'serviceItems', [
            'label'       => esc_html__( 'Service Single Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'service-title'        => esc_html__( 'Rock Solid Insurance', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'service-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Rock Solid Insurance', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],

                [
                    'name'        => 'service-des',
                    'label'       => esc_html__( 'Short Description', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Our Sustainable Construction Advisors', 'insucom-extra' ),
                    'label_block' => true,
                    'description' => esc_html__( 'Enter Description', 'insucom-extra' )
                ],

            

            ],
            'title_field' => "{{name}}"
        ] );



        $this->end_controls_section();


        // ===================== Title ======================//

        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '
                {{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h1.banner-heading' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'insucom-extra' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'insucom-extra' ),
            'selector' => '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Sub Title Color', 'insucom-extra' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .theme-banner-startup-wrapper h4.banner-sub-heading' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style

		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

        $serviceItems = $settings['serviceItems'];

        extract($settings); 


		
		?>

            <div class="border-b border-primaryBorder pb-[60px] mb-[60px] service-single-content-wrapper">
                <div
                  class="grid sm:grid-cols-2 grid-cols-1 gap-[30px] items-center mb-[60px]"
                >
                  <div class="article-area">
                    <p
                      class="sm:text-xl sm:leading-8 text-lg font-bold spline-sans text-primary-500 mb-2"
                    >
                      <?php echo wp_kses_post( $settings['title'] ); ?>
                    </p>

                    <h2 class="headline-default text-primary-900 mb-5">
                      <?php echo wp_kses_post( $settings['sub-title'] ); ?>
                    </h2>
                    <p
                      class="text-base leading-[27px] text-primary-100 mb-[60px]"
                    >
                      <?php echo wp_kses_post( $settings['description1'] ); ?>

                    </p>


                    <div class="grid sm:grid-cols-2 grid-cols-1 gap-[30px]">

                    <?php
                        foreach ( $serviceItems as $item ):
                    ?>

                      <div>
                        <p class="flex space-x-2.5 items-center">
                          <span>
                            <svg
                              width="16"
                              height="16"
                              viewBox="0 0 16 16"
                              fill="none"
                              xmlns="http://www.w3.org/2000/svg"
                            >
                              <path
                                d="M0 8C0 3.59375 3.5625 0 8 0C12.4062 0 16 3.59375 16 8C16 12.4375 12.4062 16 8 16C3.5625 16 0 12.4375 0 8ZM11.5938 6.625C11.9375 6.28125 11.9375 5.75 11.5938 5.40625C11.25 5.0625 10.7188 5.0625 10.375 5.40625L7 8.78125L5.59375 7.40625C5.25 7.0625 4.71875 7.0625 4.375 7.40625C4.03125 7.75 4.03125 8.28125 4.375 8.625L6.375 10.625C6.71875 10.9688 7.25 10.9688 7.59375 10.625L11.5938 6.625Z"
                                fill="#028835"
                              />
                            </svg>
                          </span>
                          <span
                            class="text-lg font-bold spline-sans leading-7 text-primary-900"
                            ><?php echo wp_kses_post( $item['service-title'] ); ?></span
                          >
                        </p>
                        <p class="text-base leading-[27px] text-primary-100">
                          <?php echo wp_kses_post( $item['service-des'] ); ?>
                        </p>
                      </div>

                  <?php endforeach; ?>


                    </div>
                  </div>
                  <div class="thumb">
                    <div class="w-full h-[400px] rounded overflow-hidden">
                      <img
                        src="<?php echo esc_url( $settings['section_right_image']['url'] ); ?>"
                        alt="service"
                        class="w-full h-full object-cover"
                      />
                    </div>
                  </div>
                </div>
                <p class="text-base leading-[27px] text-primary-100 mb-2.5">
                  <?php echo wp_kses_post( $settings['description2'] ); ?>
                </p>
                <p class="text-base leading-[27px] text-primary-100">
                  <?php echo wp_kses_post( $settings['description3'] ); ?>
                </p>
              </div>



	<?php 


	}
				

}

