<?php

/**
 * Elementor Widget
 * @package Insucom
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class theme_home_about_two extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'theme-about-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Home About:2', 'insucom-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'insucom_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


        $this->start_controls_section( 'section_content_title_about2', [
            'label' => esc_html__( 'About Content', 'insucom-extra' ),
        ] );


        $this->add_control( 'title', [
            'label'       => __( 'Title', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'IWhat ets us apart from the rest is our visionary', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type section title here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'default'     => __( 'Short Content', 'insucom-extra' ),
            'label_block' => true,
            'description' => __( "Type sbanner short description here.", 'insucom-extra' ),

        ] );

        $this->add_control( 'listItems', [
            'label'       => esc_html__( 'Features List Item', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'default'     => [
                [
                    'list-title'        => esc_html__( 'Be positive but realistic', 'insucom-extra' ),
                ]
            ],

            'fields'      => [

                [
                    'name'        => 'list-title',
                    'label'       => esc_html__( 'Title', 'insucom-extra' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => __( 'Be positive but realistic', 'insucom-extra' ),
                    'description' => esc_html__( 'Enter Title', 'insucom-extra' )
                ],


            ],
            'title_field' => "{{name}}"
        ] );


        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'insucom-extra' ),
            'default'     => __( 'Get in touch', 'insucom-extra' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'insucom-extra' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control( 'client_text', [
            'label'       => __( 'Client Text', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type text here', 'insucom-extra' ),
            'default'     => __( 'Satisfied Client', 'insucom-extra' ),
        ] );

        $this->add_control( 'client_number', [
            'label'       => __( 'Client Number', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type number here', 'insucom-extra' ),
            'default'     => __( '1234567', 'insucom-extra' ),
        ] );



        $this->end_controls_section();


        $this->start_controls_section( 'section_content_about_inner_img', [
            'label' => esc_html__( 'About Image Section', 'insucom-extra' ),
        ] ); 


        $this->add_control( 'about_feature_image', [
            'label'   => __( 'Choose About Image', 'insucom-extra' ),
            'type'    => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ] );

        $this->add_control(
            'video_link', [
                'label' => __( 'Insert Self Hosted Video URL Link in Video format(eg. mp4/flv etc).', 'insucom-extra' ),
                'type'        => \Elementor\Controls_Manager::URL,

                'default'     => [
                    'url' => 'https://www.youtube.com/watch?v=9Oia-ki4iyw',
                ],
                
                'description' => esc_html__( 'Enter Video URL', 'insucom-extra' )
            ]
        );


        $this->add_control( 'abt_client_text', [
            'label'       => __( 'About Client Text', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type text here', 'insucom-extra' ),
            'default'     => __( 'Daily Activity', 'insucom-extra' ),
        ] );

        $this->add_control( 'abt_client_text2', [
            'label'       => __( 'About Client Text Bottom', 'insucom-extra' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'placeholder' => __( 'Type text here', 'insucom-extra' ),
            'default'     => __( 'Loream is ispam', 'insucom-extra' ),
        ] );

    

        $this->end_controls_section();



		
	}
	


	protected function render() {
		
		
		$settings = $this->get_settings_for_display();
        $listItems = $settings['listItems'];

        extract($settings); 


		
		?>


      <!--      about section-->
      <section class="about-section-area theme-about-two-style w-full lg:py-[120px] py-[60px]">
        <div class="theme-container mx-auto">
          <div
            class="w-full grid xl:grid-cols-2 grid-cols-1 gap-10 xl:gap-0 items-center"
          >
            <div class="thumb-area relative md:w-[600px] w-full">
              <img src="<?php echo esc_url( $settings['about_feature_image']['url'] ); ?>" alt="" />
              <button
                type="button"
                onclick="videoPopup()"
                class="w-[110px] h-[110px] rounded bg-primary-500 sm:flex hidden justify-center items-center absolute right-[80px] top-[315px]"
              >
                <span>
                  <svg
                    width="18"
                    height="20"
                    viewBox="0 0 18 20"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M16.5511 8.38398L2.82309 0.267981C2.53949 0.096703 2.2153 0.00424013 1.88402 0.000142387C1.55273 -0.00395536 1.22636 0.0804605 0.93861 0.244671C0.650859 0.408882 0.412163 0.646934 0.247174 0.934239C0.0821847 1.22154 -0.0031142 1.54769 8.68912e-05 1.87898V18.11C-0.000276804 18.4402 0.0867969 18.7646 0.252456 19.0502C0.418114 19.3358 0.656451 19.5725 0.943235 19.7362C1.23002 19.8998 1.55503 19.9846 1.88521 19.982C2.2154 19.9793 2.53899 19.8893 2.82309 19.721L16.5511 11.61C16.8312 11.4447 17.0633 11.2092 17.2246 10.9268C17.3859 10.6443 17.4707 10.3247 17.4707 9.99948C17.4707 9.67424 17.3859 9.35463 17.2246 9.07219C17.0633 8.78976 16.8312 8.55427 16.5511 8.38898V8.38398Z"
                      fill="white"
                    />
                  </svg>
                </span>
              </button>
              <div
                class="w-[268px] h-[87px] rounded-full p-3 bg-white absolute md:right-[47px] right-0 md:top-[525px] top-[300px]"
                style="
                  box-shadow: 0px 4.8px 24.4px -6px rgba(19, 16, 34, 0.1),
                    0px 4px 13px -2px rgba(19, 16, 34, 0.06);
                "
              >
                <div class="flex space-x-[15px] items-center">
                  <div
                    class="w-[63px] h-[63px] rounded-full bg-secondary flex justify-center items-center"
                  >
                    <svg
                      width="36"
                      height="36"
                      viewBox="0 0 36 36"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                    >
                      <path
                        d="M33.4049 19.0345C33.6025 27.8649 25.8057 35.6541 16.9828 35.4717C8.388 35.5173 0.993959 28.5033 0.560759 19.9161C-0.123241 10.7588 7.8028 2.39958 16.9752 2.59718C17.188 2.59718 17.3552 2.77198 17.3552 2.97718V18.6545H33.0325C33.2377 18.6545 33.4049 18.8217 33.4049 19.0345Z"
                        fill="#028835"
                      />
                      <path
                        d="M35.4816 16.9646C35.4816 17.1698 35.3144 17.337 35.1016 17.337H19.0443C18.8391 17.337 18.6719 17.1698 18.6719 16.9646V0.907344C18.6719 0.694544 18.8391 0.527344 19.0443 0.527344C28.1103 0.527344 35.4816 7.89858 35.4816 16.9646Z"
                        fill="#004C3F"
                      />
                    </svg>
                  </div>
                  <div>
                    <span class="text-base font-bold text-gray-700 block">
                      <?php echo $settings['abt_client_text'] ?></span
                    >
                    <span class="text-base text-gray-700 block"
                      ><?php echo $settings['abt_client_text2'] ?></span
                    >
                  </div>
                </div>
              </div>
            </div>
            <div class="article-area">
              <h2 class="headline-default text-primary-900 mb-5">

                 <?php echo wp_kses_post( $settings['title'] ); ?>

              </h2>
              <p
                class="text-base about-two-des text-primary-100 mb-[30px] xl:max-w-full max-w-4xl"
              >

                <?php echo wp_kses_post( $settings['description'] ); ?>

              </p>
              <ul class="flex flex-col space-y-2.5 mb-8">


                <?php
                    foreach ( $listItems as $item ):
                ?>

                <li class="flex space-x-2.5 items-center">
                  <span>
                    <svg
                      width="20"
                      height="20"
                      viewBox="0 0 20 20"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                    >
                      <circle cx="10" cy="10" r="10" fill="#028835" />
                      <path
                        d="M14.2656 6.98438C14.5703 7.26562 14.5703 7.75781 14.2656 8.03906L8.26562 14.0391C7.98438 14.3438 7.49219 14.3438 7.21094 14.0391L4.21094 11.0391C3.90625 10.7578 3.90625 10.2656 4.21094 9.98438C4.49219 9.67969 4.98438 9.67969 5.26562 9.98438L7.72656 12.4453L13.2109 6.98438C13.4922 6.67969 13.9844 6.67969 14.2656 6.98438Z"
                        fill="white"
                      />
                    </svg>
                  </span>
                  <span class="lg:text-base text-sm text-primary-900"
                    ><?php echo wp_kses_post( $item['list-title'] ); ?></span
                  >
                </li>

            <?php endforeach; ?>



              </ul>
              <div class="flex space-x-10 items-center">
                <a href="<?php echo esc_url( $settings['btn_link']['url'] ) ?>">
                  <div
                    class="px-[46px] py-[20px] bg-primary-500 hover:bg-primary-900 common-trans rounded-lg text-white text-lg spline-sans leading-none"
                  >
                    <span><?php echo $settings['btn_text'] ?></span>
                  </div>
                </a>
                <a href="#" class="sm:flex hidden space-x-5 items-center">
                  <div
                    class="w-[55px] h-[55px] rounded-full flex justify-center items-center border border-primaryBorder"
                  >
                    <span class="shake">
                      <svg
                        width="21"
                        height="21"
                        viewBox="0 0 21 21"
                        fill="none"
                        xmlns="http://www.w3.org/2000/svg"
                      >
                        <path
                          d="M19.9609 15.6172L19.0234 19.5625C18.9062 20.1484 18.4375 20.5391 17.8516 20.5391C8.00781 20.5 0 12.4922 0 2.64844C0 2.0625 0.351562 1.59375 0.9375 1.47656L4.88281 0.539062C5.42969 0.421875 6.01562 0.734375 6.25 1.24219L8.08594 5.5C8.28125 6.00781 8.16406 6.59375 7.73438 6.90625L5.625 8.625C6.95312 11.3203 9.14062 13.5078 11.875 14.8359L13.5938 12.7266C13.9062 12.3359 14.4922 12.1797 15 12.375L19.2578 14.2109C19.7656 14.4844 20.0781 15.0703 19.9609 15.6172Z"
                          fill="#028835"
                        />
                      </svg>
                    </span>
                  </div>
                  <div>
                    <span class="text-lg spline-sans text-primary-900 block"
                      ><?php echo $settings['client_text'] ?></span
                    >
                    <span
                      class="font-semibold text-lg spline-sans text-primary-900 block"
                      ><?php echo $settings['client_number'] ?></span
                    >
                  </div>
                </a>
              </div>
            </div>
          </div>
        </div>
      </section>



	<?php 


	}
				

}

