<?php
/**
 * Insucom functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package insucom
 */


/**
 * define theme info
 * @since 1.0.0
 * */
 
 if (is_child_theme()){
	$theme = wp_get_theme();
	$parent_theme = $theme->Template;
	$theme_info = wp_get_theme($parent_theme);
}else{
	$theme_info = wp_get_theme();
}

define('INSUCOM_DEV_MODE',true);
$insucom_version = INSUCOM_DEV_MODE ? time() : $theme_info->get('Version');
define('INSUCOM_NAME',$theme_info->get('Name'));
define('INSUCOM_VERSION',$insucom_version);
define('INSUCOM_AUTHOR',$theme_info->get('Author'));
define('INSUCOM_AUTHOR_URI',$theme_info->get('AuthorURI'));


/**
 * Define Const for theme Dir
 * @since 1.0.0
 * */

define('INSUCOM_THEME_URI', get_template_directory_uri());
define('INSUCOM_IMG', INSUCOM_THEME_URI . '/assets/images');
define('INSUCOM_CSS', INSUCOM_THEME_URI . '/assets/css');
define('INSUCOM_JS', INSUCOM_THEME_URI . '/assets/js');
define('INSUCOM_THEME_DIR', get_template_directory());
define('INSUCOM_IMG_DIR', INSUCOM_THEME_DIR . '/assets/images');
define('INSUCOM_CSS_DIR', INSUCOM_THEME_DIR . '/assets/css');
define('INSUCOM_JS_DIR', INSUCOM_THEME_DIR . '/assets/js');
define('INSUCOM_INC', INSUCOM_THEME_DIR . '/inc');
define('INSUCOM_THEME_OPTIONS',INSUCOM_INC .'/theme-options');
define('INSUCOM_THEME_OPTIONS_IMG',INSUCOM_THEME_OPTIONS .'/img');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
*/
	 
function insucom_setup(){
	
	// make the theme available for translation
	load_theme_textdomain( 'insucom', get_template_directory() . '/languages' );
	
	// add support for post formats
    add_theme_support('post-formats', [
        'standard', 'image', 'video', 'audio','gallery'
    ]);

    // add support for automatic feed links
    add_theme_support('automatic-feed-links');

    // let WordPress manage the document title
    add_theme_support('title-tag');
	
	// add editor style theme support
	function insucom_theme_add_editor_styles() {
		add_editor_style( 'custom-style.css' );
	}
	add_action( 'admin_init', 'insucom_theme_add_editor_styles' );

    // add support for post thumbnails
    add_theme_support('post-thumbnails');
	
	// hard crop center center
    set_post_thumbnail_size(1140, 850, ['center', 'center']);
	add_image_size( 'insucom-box-slider-small', 96, 96, true );
	
	
	// register navigation menus
    register_nav_menus(
        [
            'primary' => esc_html__('Primary Menu', 'insucom'),
            'footermenu' => esc_html__('Footer Menu', 'insucom'),
        ]
    );
	
	
	// HTML5 markup support for search form, comment form, and comments
    add_theme_support('html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ));
	
	
	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 150,
		'width'       => 300,
		'flex-width'  => true,
		'flex-height' => true,
	) );
	
	
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	
	/*
     * Enable support for wide alignment class for Gutenberg blocks.
     */
    add_theme_support( 'align-wide' );
    add_theme_support( 'editor-styles' );
    add_theme_support( 'wp-block-styles' );
		
}

add_action('after_setup_theme', 'insucom_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
*/
 
function insucom_widget_init() {
	

        register_sidebar( array (
			'name' => esc_html__('Blog widget area', 'insucom'),
			'id' => 'sidebar-1',
			'description' => esc_html__('Blog Sidebar Widget.', 'insucom'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
			
		) );
		
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area One', 'insucom' ),
			'id'            => 'footer-widget-1',
			'description'   => esc_html__( 'Add Footer  widgets here.', 'insucom' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Two', 'insucom' ),
			'id'            => 'footer-widget-2',
			'description'   => esc_html__( 'Add Footer widgets here.', 'insucom' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Three', 'insucom' ),
			'id'            => 'footer-widget-3',
			'description'   => esc_html__( 'Add Footer widgets here.', 'insucom' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Four', 'insucom' ),
			'id'            => 'footer-widget-4',
			'description'   => esc_html__( 'Add Footer widgets here.', 'insucom' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Header Canvas Menu Widget', 'insucom' ),
			'id'            => 'header-one-nav-wid',
			'description'   => esc_html__( 'Add Header widgets here.', 'insucom' ),
			'before_widget' => '<div id="%1$s" class="header-panel-nav-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );
					
}

add_action('widgets_init', 'insucom_widget_init');


/**
 * Enqueue scripts and styles.
 */
function insucom_scripts() {
	
	// Theme CSS 
	
	wp_enqueue_style( 'font-awesomes', INSUCOM_CSS . '/font-awesome.css');
	wp_enqueue_style( 'icon-font',  INSUCOM_CSS . '/icon-font.css' );
	wp_enqueue_style( 'remix-font',  INSUCOM_CSS . '/remixicon.css' );
	wp_enqueue_style( 'animate',  INSUCOM_CSS . '/animate.css' );
	wp_enqueue_style( 'magnific-popup',  INSUCOM_CSS . '/magnific-popup.css' );
	wp_enqueue_style( 'owl-carousel',  INSUCOM_CSS . '/owl.carousel.min.css' );
	wp_enqueue_style( 'swipe-slider',  INSUCOM_CSS . '/swipe-slider.css' );
	wp_enqueue_style( 'owl-theme',  INSUCOM_CSS . '/owl.theme.min.css' );
	wp_enqueue_style( 'slick',  INSUCOM_CSS . '/slick.css' );
	wp_enqueue_style( 'slicknav',  INSUCOM_CSS . '/slicknav.css' );
	wp_enqueue_style( 'aos',  INSUCOM_CSS . '/aos.css' );
	wp_enqueue_style( 'output',  INSUCOM_CSS . '/output.css' );
	wp_enqueue_style( 'insucom-fonts', INSUCOM_CSS . '/theme-fonts.css', array(), '1.0', 'all');
	wp_enqueue_style( 'insucom-main',  INSUCOM_CSS . '/main.css' );
	wp_enqueue_style( 'insucom-responsive',  INSUCOM_CSS . '/responsive.css' );	
	wp_enqueue_style( 'insucom-style', get_stylesheet_uri() );
	
	// Theme JS
	
	wp_enqueue_script( 'popper',  INSUCOM_JS . '/popper.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-magnific-popup',  INSUCOM_JS . '/jquery.magnific-popup.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-appear',  INSUCOM_JS . '/jquery.appear.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'owl-carousel',  INSUCOM_JS . '/owl.carousel.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'slick', INSUCOM_JS . '/slick.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'purecounter-js', INSUCOM_JS . '/purecounter.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'swipe-slide', INSUCOM_JS . '/swipe-slider.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-slicknav', INSUCOM_JS . '/jquery.slicknav.min.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-aos', INSUCOM_JS . '/aos.js', array( 'jquery' ), '1.0', true );
	
	
	// Custom JS Scripts

	wp_enqueue_script( 'insucom-plugins',  INSUCOM_JS . '/plugins.js', array( 'jquery' ),  '1.0', true );

	wp_enqueue_script( 'insucom-scripts',  INSUCOM_JS . '/scripts.js', array( 'jquery' ),  '1.0', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	

}

add_action( 'wp_enqueue_scripts', 'insucom_scripts' );


/*
* Include codester helper functions
* @since 1.0.0
*/

if ( file_exists( INSUCOM_INC.'/cs-framework-functions.php' ) ) {
	require_once  INSUCOM_INC.'/cs-framework-functions.php';
}

if ( file_exists( INSUCOM_THEME_OPTIONS.'/theme-metabox.php' ) ) {
	require_once  INSUCOM_THEME_OPTIONS.'/theme-metabox.php';
}

if ( file_exists( INSUCOM_THEME_OPTIONS.'/theme-nav-options.php' ) ) {
	require_once  INSUCOM_THEME_OPTIONS.'/theme-nav-options.php';
}

if ( file_exists( INSUCOM_THEME_OPTIONS.'/theme-customizer.php' ) ) {
	require_once  INSUCOM_THEME_OPTIONS.'/theme-customizer.php';
}


if ( file_exists( INSUCOM_THEME_OPTIONS.'/theme-inline-styles.php' ) ) {
	require_once  INSUCOM_THEME_OPTIONS.'/theme-inline-styles.php';
}


/**
 * Required plugin installer 
*/
require get_template_directory() . '/inc/required-plugins.php';


/**
 * Custom template tags & functions for this theme.
*/
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';


/**
 * Nav walker class for this theme.
*/
require get_template_directory() . '/inc/theme-nav-walker.php';


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
*/
function insucom_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'insucom_content_width', 640 );
}

add_action( 'after_setup_theme', 'insucom_content_width', 0 );

/**
 * Nav menu fallback function
*/

function insucom_fallback_menu() {
	get_template_part( 'template-parts/default', 'menu' );
}

/**
 * Custom admin CSS hook
*/

function insucom_admin_style() {
  wp_enqueue_style( 'insucom-admin-style',  INSUCOM_CSS . '/admin-style.css' );
}

add_action( 'admin_enqueue_scripts', 'insucom_admin_style');


function insucom_enable_svg_upload( $upload_mimes ) {
    $upload_mimes['svg'] = 'image/svg+xml';
    $upload_mimes['svgz'] = 'image/svg+xml';
    return $upload_mimes;
}
add_filter( 'upload_mimes', 'insucom_enable_svg_upload', 10, 1 );