<?php
/*
 * Theme Customize Options
 * @package insucom
 * @since 1.0.0
 * */

if (!defined('ABSPATH'))
{
    exit(); // exit if access directly
    
}

if (class_exists('CSF'))
{

    $prefix = 'insucom';

    CSF::createCustomizeOptions($prefix . '_customize_options');

    // Create a top-tab
    CSF::createSection($prefix . '_customize_options', array(
        'id' => 'theme_settings', // Set a unique slug-like ID
        'title' => 'Insucom Options',
        'priority' => 10,
        'icon' => 'fa fa-heart',
    ));

    /*-------------------------------------
     ** General Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('General', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 10,
        'fields' => array(

        array(
            'type' => 'subheading',
            'content' => '<h3>' . esc_html__('Site Logo', 'insucom') . '</h3>',
        ) ,
            
        array(
            'id' => 'theme_logo',
            'title' => esc_html__('Main Logo','insucom'),
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Static Logo Image on Header Static', 'insucom')
        ), 
        
        array(
            'id' => 'theme_logo_light',
            'title' => esc_html__('Light or Transparent Logo', 'insucom') ,
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Transparent Logo Image', 'insucom')
        ) ,

        
        array(
            'id' => 'logo_width',
            'type' => 'slider',
            'title' => esc_html__('Set Logo Width','insucom'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 179,
            'desc' => esc_html__('Set Logo Width in px. Default Width 179px.', 'insucom') ,
            'output' => '.header-style-one .logo.theme-logo img',
            'output_mode' => 'width',
        ) ,
        
        array(
            'id' => 'logo_width_light',
            'type' => 'slider',
            'title' => esc_html__('Set Transparent Logo Width','insucom'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 280,
            'desc' => esc_html__('Set Logo Width in px. Default Width 280px.', 'insucom') ,
            'output' => '.transparent-header .logo.theme-logo img',
            'output_mode' => 'width',
        ) ,

      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Preloader','insucom').'</h3>'
      ),
      
      
      array(
        'id' => 'preloader_enable',
        'title' => esc_html__('Enable Preloader','insucom'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Preloader', 'insucom') ,
        'default' => true,
      ),
      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Back Top Options','insucom').'</h3>'
      ),
      
      
      array(
        'id' => 'back_top_enable',
        'title' => esc_html__('Scroll Top Button','insucom'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable scroll button', 'insucom') ,
        'default' => true,
      ),




        )

    ));

    /*-------------------------------------
     ** Header Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Header', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 11,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header Layout', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'nav_menu',
                'type' => 'image_select',
                'title' => esc_html__('Select Header Layout', 'insucom') ,
                'options' => array(
                    'nav-style-one' => INSUCOM_IMG . '/admin/header-style/style1.png',
                    'nav-style-two' => INSUCOM_IMG . '/admin/header-style/style2.png',
                ) ,
                'default' => 'nav-style-one'
            ) ,

            array(
                    'id' => 'theme_header_sticky',
                    'title' => esc_html__('Sticky Header', 'insucom') ,
                    'type' => 'switcher',
                    'desc' => esc_html__('Enable Sticky Header', 'insucom') ,
                    'default' => false,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Header 1 - Components', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'header_btn_text_one',
                'type' => 'text',
                'title' => 'Top Left Text 1',
                'default' => esc_html__('6391 Elgin St. Celina, 10299', 'insucom') ,
            ) ,

            array(
                'id' => 'header_btn_text_two',
                'type' => 'text',
                'title' => 'Top Left Text 2',
                'default' => esc_html__('9 am - 8 pm', 'insucom') ,
            ) ,

            array(
                'id' => 'header_btn_text_quote',
                'type' => 'text',
                'title' => 'Quote Button Text',
                'default' => esc_html__('Get a quote', 'insucom') ,
            ) ,

            array(
                'id' => 'header_btn_link_quote',
                'type' => 'text',
                'title' => 'Quote Button Link',
                'default' => '#',
            ) ,

            array(
                'id' => 'header_btn_text_call',
                'type' => 'text',
                'title' => 'Call Button Text',
                'default' => esc_html__('Requesting A Call:', 'insucom') ,
            ) ,

            array(
                'id' => 'header_btn_text_number',
                'type' => 'text',
                'title' => 'Quote Button Number',
                'default' => '#',
            ) ,

            array(
                'id' => 'header_btn_email_url',
                'type' => 'text',
                'title' => 'Header Email Adress',
                'default' => '#',
            ) ,




            array(
                'id' => 'search_bar_enable',
                'title' => esc_html__('Search Box','insucom'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Search Box', 'insucom') ,
                'default' => true,
            ),

            array(
                'id' => 'burger_nav_enable',
                'title' => esc_html__('Right Burger Menu','insucom'),
                'type' => 'switcher',
                'desc' => esc_html__('Enable or Disable Burger Menu', 'insucom') ,
                'default' => true,
            ),


            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Social Network', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'header_social_enable',
                'title' => esc_html__('Show Header Social Icons', 'insucom') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Header Social Icons', 'insucom') ,
                'default' => true,
            ) ,

            array(
                'id' => 'header-social-icon',
                'type' => 'repeater',
                'title' => 'Add New Social',
                'fields' => array(

                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Pick Up Your Social Icon', 'insucom') ,
                    ) ,

                    array(
                        'id' => 'link',
                        'type' => 'text',
                        'title' => esc_html__('Inter Social Url', 'insucom') ,
                    ) ,

                ) ,
            ) ,

        )

    ));

    /*-------------------------------------
     ** Color Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Colors', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 12,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Choose Theme Color', 'insucom') . '</h3>',
            ) ,

            array(
                'id' => 'theme_main_color',
                'type' => 'color',
                'title' => esc_html__('Primary Color', 'insucom') ,
                'default' => '#000000',
            ) ,


            array(
                'id' => 'theme_body_bg',
                'type' => 'color',
                'title' => esc_html__('Body Background Color', 'insucom') ,
                'default' => '#fff',
                'output'      => 'body',
                'output_mode' => 'background-color'
            ) ,

            array(
                'id' => 'theme_body_text',
                'type' => 'color',
                'title' => esc_html__('Body Text Color', 'insucom') ,
                'default' => '#000000',
                'output'      => 'body',
                'output_mode' => 'color'
            ) ,



        )

    ));




    /*-------------------------------------
     ** Typography Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Typography', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 14,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Body', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'body-typography',
                'type' => 'typography',
                'output' => 'body',
                'default' => array(
                    'font-family' => 'DM Sans',
                    'font-weight' => '400',
                    'font-size' => '18',
                    'line-height' => '26',
                    'letter-spacing' => '0',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                ) ,

            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'heading-one-typo',
                'type' => 'typography',

                'output' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
                'default' => array(
                    'color' => '#000',
                    'font-family' => 'Spline Sans',
                    'font-weight' => '700',
                    'subset' => 'latin-ext',
                    'text-align' => 'inherit',
                    'font-size' => false,
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,


            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Navigation', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'nav-typography',
                'type' => 'typography',
                //'output' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
                'default' => array(
                    'color' => '#000',
                    'font-family' => 'Montserrat',
                    'font-weight' => '700',
                    'subset' => 'latin-ext',
                    'text-align' => 'left',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,

        )
    ));

    /*-------------------------------------
     **Blog Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Blog: Listing', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 15,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Blog Options', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => 'Blog Page Title',
                'default' => 'Blog Page',
                'desc' => 'Type Blog Page Title',
            ) ,

            array(
                'id' => 'page-spacing-blog',
                'type' => 'spacing',
                'title' => 'Blog Page Spacing',
                'output' => '.main-container.blog-spacing',
                'output_mode' => 'padding', // or margin, relative
                'default' => array(
                    'top' => '80',
                    'right' => '0',
                    'bottom' => '80',
                    'left' => '0',
                    'unit' => 'px',
                ) ,
            ) ,

            array(
                'id' => 'blog_breadcrumb_enable',
                'title' => esc_html__('Breadcrumb', 'insucom') ,
                'type' => 'switcher',
                'desc' => esc_html__('Enable Breadcrumb', 'insucom') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_thumb',
                'title' => esc_html__('Show Post Image', 'insucom') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog Image', 'insucom') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_cat',
                'title' => esc_html__('Show Catgeories', 'insucom') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog category', 'insucom') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_date',
                'title' => esc_html__('Show Date', 'insucom') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Blog date', 'insucom') ,
                'default' => true,
            ) ,

            array(
                'id' => 'show_blog_excerpt',
                'title' => esc_html__('Show Excerpt', 'insucom') ,
                'type' => 'switcher',
                'desc' => esc_html__('Show Post Excerpt', 'insucom') ,
                'default' => true,
            ) ,

            array(
                'id' => 'set_blog_excerpt_limit',
                'type' => 'text',
                'title' => 'Post Excerpt Length',
                'default' => 32,
                'desc' => 'Set Blog Page Excerpt Length',
            ) ,

        )
    ));

    /*-------------------------------------
     **Category Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Category: Listing', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 16,
        'fields' => array(


        array(
            'id' => 'cat_breadcrumb_enable',
            'title' => esc_html__('Breadcrumb', 'insucom') ,
            'type' => 'switcher',
            'desc' => esc_html__('Enable Breadcrumb', 'insucom') ,
            'default' => true,
        ) ,

        array(
        'id' => 'page-spacing-category',
        'type' => 'spacing',
        'title' => esc_html__('Category Page Spacing','insucom'),
        'output' => '.main-container.cat-page-spacing',
        'output_mode' => 'padding', // or margin, relative
        'default' => array(
            'top' => '75',
            'right' => '0',
            'bottom' => '75',
            'left' => '0',
            'unit' => 'px',
        ) ,
        ) ,

        array(
            'id' => 'cat_page_categroy',
            'title' => esc_html__('Show Catgeories', 'insucom') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Blog category', 'insucom') ,
            'default' => true,
        ) ,


        )
    ));

    /*-------------------------------------
     **Single Blog Settings
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Blog: Single Post', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 17,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Theme Blog Post Options. You can Customize Each Post by Editing Individually.', 'insucom') . '</h3>'
            ) ,

      
       array(
            'id' => 'insucom_single_blog_layout',
            'type' => 'image_select',
            'title' => esc_html__('Select Single Blog Style','insucom'),
            'options' => array(
                'single-one' => INSUCOM_IMG . '/admin/page/blog-1.png',
                'single-two' => INSUCOM_IMG . '/admin/page/blog-2.png',
            ),
            'default' => 'single-one'
        ),
        
        array(
            'id' => 'post-spacing-single',
            'type' => 'spacing',
            'title' => esc_html__('Single Blog Spacing','insucom'),
            'output' => '.single-one-bwrap',
            'output_mode' => 'padding', // or margin, relative
            'default' => array(
                'top' => '85',
                'right' => '0',
                'bottom' => '40',
                'left' => '0',
                'unit' => 'px',
            ) ,
        ) ,
        
        array(
            'id' => 'show_blog_details_thumb',
            'title' => esc_html__('Post Featured Image', 'insucom') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Blog Featured Image', 'insucom') ,
            'default' => true,
        ) ,
    
        array(
            'id' => 'blog_single_cat',
            'title' => esc_html__('Post Catgeory','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Category Meta','insucom'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_single_author',
            'title' => esc_html__('Post Author','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Author Meta','insucom'),
            'default' => true,
        ),

        array(
            'id' => 'blog_single_date',
            'title' => esc_html__('Post Date', 'insucom') ,
            'type' => 'switcher',
            'desc' => esc_html__('Show Date Meta', 'insucom') ,
            'default' => true,
        ) ,

        array(
            'id' => 'blog_social',
            'title' => esc_html__('Social Share Box','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Social Share Box','insucom'),
            'default' => false,
        ),

        array(
            'id' => 'blog_tags',
            'title' => esc_html__('Show Tags','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Tags','insucom'),
            'default' => false,
        ),

        array(
            'id' => 'blog_author_box',
            'title' => esc_html__('Author Box','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Author Box','insucom'),
            'default' => false,
        ),


        array(
            'id' => 'blog_nav',
            'title' => esc_html__('Show Navigation','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Post Navigation','insucom'),
            'default' => true,
        ),

        array(
            'id'         => 'blog_prev_title',
            'type'       => 'text',
            'title'      => esc_html__('Previous Post Text','insucom'),
            'default'    => esc_html__('Previous Post','insucom'),
            'desc'       => esc_html__('Type Previous Post Link Title','insucom'),
        ),
        
        array(
            'id'         => 'blog_next_title',
            'type'       => 'text',
            'title'      => esc_html__('Next Post Text','insucom'),
            'default'    => esc_html__('Next Post','insucom'),
            'desc'       => esc_html__('Type Next Post Link Title','insucom'),
        ),
        
        
        array(
            'id' => 'blog_related',
            'title' => esc_html__('Show Related Posts','insucom'),
            'type' => 'switcher',
            'desc' => esc_html__('Related Posts','insucom'),
            'default' => false,
        ),    


        )
    ));

    /*-------------------------------------
     ** Error Page Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Error Page', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 18,
        'fields' => array(

            array( //nav bar one start
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('404 Options', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'error_title',
                'type' => 'text',
                'title' => 'Error Page Title',
                'default' => 'OOPS THAT PAGE CANT BE FOUND',
            ) ,

            array(
                'id' => 'error_btn_text',
                'type' => 'text',
                'title' => 'Error Page Button Text',
                'default' => 'Go To Homepage',
            ) ,

            array(
                'id' => 'page-spacing-error',
                'type' => 'spacing',
                'title' => 'Page Spacing',
                'output' => 'body.error404 .main-container',
                'output_mode' => 'padding', // or margin, relative
                'default' => array(
                    'top' => '75',
                    'right' => '0',
                    'bottom' => '75',
                    'left' => '0',
                    'unit' => 'px',
                ) ,
            ) ,

        )
    ));


/*-------------------------------------------------------
   ** Woocommerce  Options
--------------------------------------------------------*/
    
  CSF::createSection($prefix . '_customize_options', array(
    'title'  => esc_html__('Shop','insucom'),
    'id' => 'cat_page',
    'icon' => 'fa fa-pencil-square-o',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' => '<h3>' . esc_html__('Shop Layout', 'insucom') . '</h3>'
      ),
      
      
        array(
            'id' => 'shop_layout',
            'type' => 'image_select',
            'title' => esc_html__('Shop Layout','insucom'),
            'options' => array(
             
                'right-sidebar' => INSUCOM_IMG . '/admin/header-style/R.png',
                'left-sidebar' => INSUCOM_IMG . '/admin/header-style/L.png',
                'no-sidebar' => INSUCOM_IMG . '/admin/header-style/D.png',
            ),
            
            'default' => 'right-sidebar'
        ),


        )
    ));
	
	
    /*-------------------------------------
     ** Footer Options
     -------------------------------------*/
    CSF::createSection($prefix . '_customize_options', array(
        'title' => esc_html__('Footer Settings', 'insucom') ,
        'parent' => 'theme_settings',
        'priority' => 21,
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Layout', 'insucom') . '</h3>'
            ) ,

            array(
                'id' => 'footer_style',
                'type' => 'image_select',
                'title' => esc_html__('Select Footer Layout', 'insucom') ,
                'options' => array(
                    'footer-style-one' => INSUCOM_IMG . '/admin/header-style/footer-1.png',
                    'footer-style-two' => INSUCOM_IMG . '/admin/header-style/footer-2.png',
                ) ,
                'default' => 'footer-style-one'
            ) ,

            array(
                'id' => 'copyright_text',
                'title' => esc_html__('Display Copyright Area for Footer 2', 'insucom') ,
                'type' => 'textarea',
            ) ,

            array(
                'id' => 'footer_btn_link',
                'type' => 'text',
                'title' => 'Call to Action Button Text',
                'default' => esc_html__('#', 'insucom') ,
            ) ,

            array(
                'id' => 'footer_nav',
                'title' => esc_html__('Do You want to Show Footer Bottom Menu', 'insucom') ,
                'type' => 'switcher',
                'default' => false,
            ) ,

            array(
                'id' => 'footer_social_enable',
                'title' => esc_html__('Do You want to Show Footer Social Icons', 'insucom') ,
                'type' => 'switcher',
                'default' => false,
            ) ,

            

            array(
                'id' => 'social-icon',
                'type' => 'repeater',
                'title' => 'Repeater',
                'dependency' => array(
                    'footer_social_enable',
                    '==',
                    'true'
                ) ,
                'fields' => array(
                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Pick Up Your Social Icon', 'insucom') ,
                    ) ,
                    array(
                        'id' => 'link',
                        'type' => 'text',
                        'title' => esc_html__('Inter Social Url', 'insucom') ,
                    ) ,
                ) ,
            ) ,
        )
    ));




}

