<?php
/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package insucom
 */

$insucom_logo = insucom_get_customize_option("theme_logo");
$insucom_logo_id =
    isset($insucom_logo["id"]) && !empty($insucom_logo["id"])
        ? $insucom_logo["id"]
        : "";
$insucom_logo_url = isset($insucom_logo["url"]) ? $insucom_logo["url"] : "";
$insucom_logo_alt = get_post_meta(
    $insucom_logo_id,
    "_wp_attachment_image_alt",
    true
);

$header_btn_text_number = insucom_get_customize_option(
    "header_btn_text_number"
);
$header_btn_text_one = insucom_get_customize_option("header_btn_text_one");
$footer_btn_link = insucom_get_customize_option("footer_btn_link");

$insucom_header_social = insucom_get_customize_option("header_social_enable");
$insucom_social_icon = insucom_get_customize_option("header-social-icon");

$footer_nav = insucom_get_customize_option("footer_nav");

$scroll_top = insucom_get_customize_option("back_top_enable", true);
$footer_copyright_text = insucom_get_customize_option("copyright_text");
$footer_copyright_text_allowed_tags = [
    "a" => [
        "href" => [],
        "title" => [],
    ],
    "img" => [
        "alt" => [],
        "src" => [],
    ],
    "br" => [],
    "em" => [],
    "strong" => [],
];
?>



<footer>
  <section class="footer-wrapper-two w-full bg-secondary relative">
    <div class="theme-container mx-auto relative">
      <div class="discover-area z-20 w-full sm:h-[253px] h-[300px] rounded-[10px] left-0 absolute -top-[125px] lg:px-[60px] p-5 sm:px-[42px] flex sm:flex-row flex-col space-y-14 sm:space-y-0 sm:justify-between sm:items-center">
        <div>
          <p class="text-base leading-7 text-white mb-1">
            <?php esc_html_e("For your car we will do everything", "insucom"); ?>
          </p>
          <h2 class="headline-default text-white">
            <?php esc_html_e('Let\'s get your insurance', "insucom"); ?>
          </h2>
        </div>
        <div>
          <a href="<?php echo esc_url($footer_btn_link); ?>">
            <div class="lg:px-10 hover:border-transparent inline lg:py-6 px-8 py-5 border border-white hover:bg-white common-trans rounded-lg text-lg font-semibold leading-4 spline-sans text-white hover:text-primary-500">
              <?php esc_html_e("Discover More", "insucom"); ?>
            </div>
          </a>
        </div>
      </div>
    </div>
    <div class="theme-container mx-auto relative z-10">
      <div class="w-full pt-[210px]">
        <div class="grid lg:grid-cols-4 sm:grid-cols-3 grid-cols-1 gap-[30px] items-center lg:justify-between pb-[60px] mb-10 border-b border-primaryBorder">

          <?php if (has_custom_logo() || !empty($insucom_logo_url)) {
         if (isset($insucom_logo["url"]) && !empty($insucom_logo_url)) { ?>
          <a href="<?php echo esc_url(site_url("/")); ?>" class="block footer-logo">
            <img src="<?php echo esc_url($insucom_logo_url); ?>" alt="<?php echo esc_attr(
    $insucom_logo_alt
); ?>">
          </a>
          <?php } else {the_custom_logo();}
     } else {
         printf(
             '<h1 class="text-logo"><a href="%1$s">%2$s</a></h1>',
             esc_url(site_url("/")),
             esc_html(get_bloginfo("name"))
         );
     } ?>


          <div class="flex space-x-[17px] items-center">
            <div class="w-[60px] h-[60px] rounded-full flex justify-center items-center bg-white">
              <span>
                <img src="<?php echo INSUCOM_IMG .
            "/pin.svg"; ?>" alt="" class="footer-icon-img">
              </span>
            </div>
            <div>
              <p class="text-lg font-semibold spline-sans leading-[27px] mb-1.5 text-primary-900">
                <?php esc_html_e("Our Address", "insucom"); ?>
              </p>
              <p class="text-base leading-[27px] text-primary-100">
                <?php if ($header_btn_text_one):
            echo esc_html($header_btn_text_one);
        else:
            echo esc_html__("6391 Elgin St. Celina, 10299", "insucom");
        endif; ?>
              </p>
            </div>
          </div>
          <div class="flex space-x-[17px] items-center">
            <div class="w-[60px] h-[60px] rounded-full flex justify-center items-center bg-white">
              <span>
                <img src="<?php echo INSUCOM_IMG .
            "/call-icon.svg"; ?>" alt="" class="footer-icon-img">
              </span>
            </div>
            <div>
              <p class="text-lg font-semibold spline-sans leading-[27px] mb-1.5 text-primary-900">
                <?php esc_html_e("Phone Number", "insucom"); ?>
              </p>
              <p class="text-base leading-[27px] text-primary-100">
                <?php if ($header_btn_text_number):
            echo esc_html($header_btn_text_number);
        else:
            echo esc_html__("(629) 555-0129", "insucom");
        endif; ?>
              </p>
            </div>
          </div>
          <div class="flex lg:justify-end">
            <div class="flex space-x-2.5 items-center">

              <?php if (!empty($insucom_social_icon)):
           foreach ($insucom_social_icon as $item): ?>

              <a href="<?php echo esc_url(
           $item["link"]
       ); ?>" class="transform translate-y-0 hover:-translate-y-1 common-trans">
                <div class="w-10 h-10 rounded-full bg-white flex justify-center items-center footer-social-item">
                  <i class="<?php echo esc_attr($item["icon"]); ?>"></i>
                </div>
              </a>

              <?php endforeach;
       endif; ?>


            </div>
          </div>
        </div>
        <div class="grid lg:grid-cols-4 sm:grid-cols-2 grid-cols-1 gap-[30px] lg:gap-0 pb-[80px] border-b border-primaryBorder">

          <?php if (is_active_sidebar("footer-widget-1")): ?>
          <div class="article footer-widget-one-wrap">
            <?php dynamic_sidebar("footer-widget-1"); ?>
          </div>
          <?php endif; ?>

          <?php if (is_active_sidebar("footer-widget-2")): ?>
          <div class="colum-1 footer-widget-two-wrap">
            <?php dynamic_sidebar("footer-widget-2"); ?>
          </div>
          <?php endif; ?>


          <?php if (is_active_sidebar("footer-widget-3")): ?>
          <div class="colum-2 footer-widget-three-wrap">
            <?php dynamic_sidebar("footer-widget-3"); ?>
          </div>
          <?php endif; ?>

          <?php if (is_active_sidebar("footer-widget-4")): ?>
          <div class="colum-3 footer-widget-four-wrap">

            <?php dynamic_sidebar("footer-widget-4"); ?>

          </div>
          <?php endif; ?>



        </div>

        <div class="w-full h-[90px] flex justify-between items-center">
          <p class="text-base leading-[27px] text-primary-900">

            <?php if (!empty($footer_copyright_text)) {
          echo wp_kses(
              $footer_copyright_text,
              $footer_copyright_text_allowed_tags
          );
      } else {
          esc_html_e(
              "Copyright &copy; Insucom 2023. All rights reserved",
              "insucom"
          );
      } ?>

          </p>

          <?php if ($footer_nav == true): ?>
          <?php if (has_nav_menu("footermenu")) {
         wp_nav_menu([
             "theme_location" => "footermenu",
             "theme_location" => "footermenu",
             "menu_class" =>
                 "lg:flex hidden space-x-[30px] items-center footer-nav",
             "container" => "",
         ]);
     } ?>
          <?php endif; ?>


        </div>
      </div>
    </div>
    <div class="absolute top-[250px] right-0">
      <img src="<?php echo INSUCOM_IMG .
       "/footer-two-shape.png"; ?>" alt="" class="footer-shape-img">
    </div>
  </section>

  <?php if ($scroll_top == true): ?>
  <div class="backtotop">
    <a href="#" class="icofont-long-arrow-up" aria-hidden="true"></a>
  </div>
  <?php endif; ?>


</footer>